"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const api_1 = require("../api");
let api = api_1.Api.instance();
let host = process.env.TRIP_SERVER || 'admin-api.acc.com';
beforeEach(() => {
    api.hostname = host;
});
test('the api exists', () => {
    expect(api).not.toBe(null);
});
test('the organization is correct', () => {
    expect(api.organization).toBe(host);
});
describe("server based tests", () => {
    beforeAll((done) => {
        api.checkServerIsUp(60).then(() => done());
    }, 60000);
    test('prelogin for admin-api.acc.com should succeed', done => {
        api.prelogin().then((value) => {
            expect(value.validURI).toBe(true);
            done();
        }).catch((e) => {
            done(e);
        });
    });
    test('prelogin for localhost should fail', done => {
        api.hostname = 'localhost';
        api.prelogin().then((value) => {
            fail("it should not succeed");
        }).catch((e) => {
            expect(e).toBe('/error/unknownuri');
            done();
        });
    });
    test('login should succeed', done => {
        api.login('admin', 'baggins')
            .then((value) => {
            expect(value.response).toBe(true);
            expect(value.status).toBe('200');
            expect(typeof value.token).toBe('string');
            api.logout().then(() => {
                done();
            });
        }).catch((e) => {
            done(e);
        });
    });
});
//# sourceMappingURL=api.test.js.map