import { UserPreferences } from './user_preferences';
import dayjs from "dayjs";
import { DateTime } from "./model/nested/datetime";
declare type Callback = (result: any) => void;
export declare type Maybe<T> = T | null;
/**
 * The EventBus interface allows messages to be sent around the application.
 * Typically in an application this will be an instance of the Vue class
 */
export interface EventBus {
    $emit(name: string, value: any): void;
    $on(name: string, callback: Callback): void;
}
/**
 * DataStore is a global state store.
 */
export interface DataStore {
    setItem(key: string, value: string): void;
    getItem(key: string): Maybe<string>;
}
export declare class Api {
    get EVENT_TYPES(): any;
    private socket?;
    private requests;
    private requestID;
    private connected;
    private openSocketPromise;
    events: Maybe<EventBus>;
    partialConnection: any;
    isAdmin: boolean;
    hostname: string;
    port: string;
    isSsl: boolean;
    localStorage: DataStore;
    sessionStorage: DataStore;
    activeCompany: any;
    loginCompany: any;
    distanceUnit: string;
    heightUnit: string;
    weigthUnit: string;
    countryCode: string;
    tz: string;
    dtAppLongFormat: string;
    dtAppFormat: string;
    dateAppFormat: string;
    get dayjs(): any;
    get now(): dayjs.Dayjs;
    get nowDT(): DateTime;
    get nowFmt(): string;
    get nowLocal(): dayjs.Dayjs;
    get nowLocalDT(): DateTime;
    ts2dt(timestamp: any): DateTime;
    asServerDT(dt: string): any;
    fmtDT(dt: any, format?: string): string;
    fmtDate(date: string, format?: string): string;
    get DTFormat(): string;
    get DateFormat(): string;
    notifyRefreshData(): void;
    localDT(dt: any): any;
    localDTFmt(dt: any, format?: string): any;
    localDateFmt(dt: any, format?: string): any;
    static instance(): Api;
    get organization(): string;
    get domain(): string;
    private uri;
    getUriForHost(host: any): string;
    get isConnected(): boolean;
    set isConnected(value: boolean);
    get loginCompanyID(): number;
    set loginCompanyID(value: number);
    get activeCompanyID(): number;
    set activeCompanyID(value: number);
    set sessionIdentityID(value: number);
    get sessionIdentityID(): number;
    get sessionUserName(): string;
    get sessionToken(): string;
    set sessionToken(token: string);
    setActiveCompanyID(value: string, navigate?: boolean): Promise<any>;
    notify(name: string, value: any): void;
    close(): void;
    private resetSessionVariables;
    prelogin(): Promise<any>;
    checkServerIsUp(retries?: number): Promise<void>;
    activate(payload: any): Promise<any>;
    private _openSocket;
    private _resumeLogin;
    resumeLogin(): Promise<any>;
    get userAlerts(): any[];
    set userAlerts(alerts: any[]);
    get userPreferences(): UserPreferences;
    set userPreferences(pref: UserPreferences);
    login(username: string, password: string, token?: string): Promise<any>;
    logout(): Promise<any>;
    navigateHome(): void;
    navigateAdminLanding(): void;
    continueLogin(parameters?: any): Promise<any>;
    isTrue(value: any): boolean;
    onLoginSuccessful(token: string, navigate: boolean): Promise<any>;
    onLoginFailed(result: any): Promise<any>;
    log(label: string, data: any): void;
    private handleMessage;
    handleMaybeNotificationMessage(data: any): void;
    private deleteRequest;
    operation(operation: string, parameters?: any): Promise<any>;
    query(name: string, parameters?: any[]): Promise<any>;
    queryPaginated(name: string, pagination?: any): Promise<any>;
    search(name: string, options?: any, parameters?: any[]): Promise<any>;
    queryWithMap(name: string, filters?: any): Promise<any>;
    searchWithMap(name: string, options?: any, parameters?: any): Promise<any>;
    sendEmailTemplate(to: string, from: string, template: string, data: any): Promise<any>;
    sendACCNewAccountEmail(to: string, username: string, uri: string, expiration: string): Promise<any>;
    read(operation: string, id: string): Promise<any>;
    create(operation: string, entity: any): Promise<any>;
    update(operation: string, entity: any): Promise<any>;
    upsert(operation: string, entity: any, reference?: string): Promise<any>;
    delete(operation: string, id: string): Promise<number>;
    callTypes(): Promise<any[]>;
}
export {};
