"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CompanyHelper = exports.COMPANY_FILTER = void 0;
const api_1 = require("../api");
const helper_1 = require("../helper");
const company_1 = require("../model/company");
const dialogs_1 = require("../dialogs");
const utility_1 = require("../utility");
exports.COMPANY_FILTER = {
    ALL: "0",
    CARER: "1",
    DIPATCH: "2"
};
class CompanyHelper {
    constructor() {
        this.api = api_1.Api.instance();
        this.helper = helper_1.Helper.instance();
    }
    marketMembers(market_id, limit, namesearch, filters) {
        return new Promise((resolve, reject) => {
            let pagination = new utility_1.Pagination("company_name");
            pagination.params.push(market_id);
            if (namesearch != "") {
                pagination.setFilter("company_name", [namesearch], "*");
            }
            if (filters && filters.length > 0) {
                for (let filter of filters) {
                    pagination.setFilter(filter.column, filter.value, filter.operator);
                }
            }
            let options = pagination.getRequestOptions(0, limit);
            return this.api
                .queryPaginated("market_company.readall_by_market", options)
                .then((page) => {
                resolve(page.data);
            }).catch(error => {
                this.api.log("COMPANYHELPER.marketMembers.error", error);
                if (dialogs_1.instance) {
                    dialogs_1.instance.alert("Error", error.message);
                }
                reject([]);
            });
        });
    }
    membersAcrossAllMyMarkets(limit, namesearch, filters) {
        return new Promise((resolve, reject) => {
            let pagination = new utility_1.Pagination("company_name");
            if (namesearch != "") {
                pagination.setFilter("company_name", [namesearch], "*");
            }
            if (filters && filters.length > 0) {
                for (let filter of filters) {
                    pagination.setFilter(filter.column, filter.value, filter.operator);
                }
            }
            let options = pagination.getRequestOptions(0, limit);
            return this.api
                .queryPaginated("market_members.distinct_across_all_markets", options)
                .then((page) => {
                resolve(page.data);
            }).catch(error => {
                this.api.log("COMPANYHELPER.membersInAnyMarket.error", error);
                if (dialogs_1.instance) {
                    dialogs_1.instance.alert("Error", error.message);
                }
                reject([]);
            });
        });
    }
    companieslist(company_id, filter, params) {
        return new Promise((resolve, reject) => {
            this.api.operation("company.public.readall", params).then((page) => {
                let res = page.data
                    .map((c) => {
                    return this.helper.ObjectClone(new company_1.Company(), c);
                }).filter((company) => {
                    let show = true;
                    if (filter == exports.COMPANY_FILTER.CARER ||
                        filter == exports.COMPANY_FILTER.DIPATCH) {
                        let onlyDispatch = (filter == exports.COMPANY_FILTER.DIPATCH);
                        let isTransportProvider = company.company_type_properties &&
                            company.company_type_properties.transport_provider;
                        let isCareProvider = company.company_type_properties &&
                            company.company_type_properties.care_provider;
                        show = onlyDispatch ? isTransportProvider : isCareProvider;
                    }
                    return company.company_id != company_id && show;
                });
            }).catch(error => {
                this.api.log("COMPANYHELPER.companieslist.error", error);
                if (dialogs_1.instance) {
                    dialogs_1.instance.alert("Error", error.message);
                }
                reject([]);
            });
        });
    }
}
exports.CompanyHelper = CompanyHelper;
//# sourceMappingURL=companies.js.map