"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ItineraryHelper = void 0;
const trip_status_1 = require("../const/trip_status");
const itinerary_1 = require("../model/itinerary");
const booking_allowed_actions_1 = require("../const/booking_allowed_actions");
const trip_1 = require("./trip");
const legbase_1 = require("./legbase");
const utility_1 = require("../utility");
const dialogs_1 = require("../dialogs");
const log_1 = require("./log");
const itinerary_type_1 = require("../const/itinerary_type");
class ItineraryHelper extends legbase_1.LegBase {
    constructor() {
        super();
    }
    setDispatchVariables(itinerary) {
        return new Promise((resolve, reject) => {
            Promise.all([this.refreshCallTypes(),
                this.refreshPriorities(),
                this.refreshVariables()]).then(res => {
                let leg = itinerary.aLeg;
                this.api.operation("trip.set_variables", leg).then((res) => {
                    if (res.error) {
                        reject(res.error);
                    }
                    else {
                        leg.properties.priority_lov_id = res.properties.priority_lov_id;
                        //this.api.log("VARIABLES.0", res.properties.priority_lov_id);
                        let item = this.helper.getArrayItem(this.priorities, "lov_alias_lov_id", res.properties.priority_lov_id);
                        //this.api.log("VARIABLES.1", item);
                        if (item) {
                            //this.api.log("VARIABLES.2", item);
                            itinerary.properties.details.addPriority(item);
                        }
                        //this.api.log("VARIABLES.3", { a: res, b: res.properties });
                        let vars = this.helper.getArrayItems(this.variables, "lov_alias_lov_id", res.properties.dispatch_variables_lov_id);
                        if (vars) {
                            vars.forEach((lov) => {
                                itinerary.properties.details.addVariable(lov);
                            });
                        }
                        resolve(res);
                    }
                }).catch(e => {
                    reject(e);
                });
            }).catch(e => {
                reject(e);
            });
        });
    }
    isFailed(item) {
        //
        // Itinerary states are now only offered, active, completed
        // the batch has the status
        //
        return item.itinerary_status.toLowerCase() == trip_status_1.TRIP_STATUS.FAILED.toLowerCase();
    }
    isExpired(item) {
        return item.itinerary_status.toLowerCase() == trip_status_1.TRIP_STATUS.EXPIRED.toLowerCase();
    }
    isUnfulfilled(item) {
        return item.itinerary_status.toLowerCase() == trip_status_1.TRIP_STATUS.EXPIRED.toLowerCase();
    }
    isCancelled(item) {
        return item.itinerary_status.toLowerCase() == trip_status_1.TRIP_STATUS.CANCELLED.toLowerCase();
    }
    isCompleted(item) {
        return item.itinerary_status.toLowerCase() == trip_status_1.TRIP_STATUS.COMPLETED.toLowerCase();
    }
    isFinalState(item) {
        return this.isCompleted(item) || this.isCancelled(item);
    }
    isOffered(item) {
        return item.itinerary_status.toLowerCase() == trip_status_1.TRIP_STATUS.OFFERED.toLowerCase();
    }
    isAccepted(item) {
        return item.itinerary_status.toLowerCase() == trip_status_1.TRIP_STATUS.ACCEPTED.toLowerCase();
    }
    isAccepting(item) {
        return item.itinerary_status.toLowerCase() == trip_status_1.TRIP_STATUS.ACCEPTING.toLowerCase();
    }
    isVipOffer(item) {
        return item.trip_offer_tier == -1 || item.trip_offer_tier == "vip";
    }
    canAddLeg(item) {
        return this.canDoIt(item.itinerary_type, item.trip_status, this.isTransportProvider, "ADD_LEG");
    }
    canResubmit(item) {
        return this.canDoIt(item.itinerary_type, item.trip_status, this.isTransportProvider, "RESUBMIT");
    }
    canAccept(item) {
        return this.canDoIt(item.itinerary_type, item.trip_status, this.isTransportProvider, "ACCEPT");
    }
    canDecline(item) {
        return this.canDoIt(item.itinerary_type, item.trip_status, this.isTransportProvider, "DECLINE");
    }
    canCancel(item) {
        return this.canDoIt(item.itinerary_type, item.itinerary_status, this.isTransportProvider, "CANCEL");
    }
    canRate(item) {
        return this.canDoIt(item.itinerary_type, item.trip_status, this.isTransportProvider, "RATE");
    }
    canComplete(item) {
        //let now = this.api.now;
        //let dt = this.api.dayjs.tz(item.trip_pick_up_dt);
        //let diff = this.api.dayjs.tz(item.trip_pick_up_dt).diff(this.api.now, "second");
        //if (diff < 0 && cando) {
        //    this.api.log("canComplete", { o: item.trip_pick_up_dt, dt: dt, now: now, diff: diff, cando });
        //}
        let diff = this.api.dayjs.tz(item.trip_pick_up_dt).diff(this.api.now, "second");
        let cando = this.canDoIt(item.itinerary_type, item.trip_status, this.isTransportProvider, "COMPLETE");
        return diff < 0 && cando;
    }
    canCreateLike(item) {
        return !this.isTransportProvider;
    }
    needsReview(leg) {
        if (this.isTransportProvider) {
            return leg.properties.transporter_review;
        }
        return leg.properties.originator_review;
    }
    canDoIt(type, status, isTransportProvider, action) {
        let statusx = status ? status.toUpperCase() : '';
        let typex = type.toUpperCase();
        let providerType = isTransportProvider ? "DISPATCH" : "CARER";
        return this.canPerformAction(typex, statusx, providerType, action);
    }
    canUnableToService(item) {
        return this.canDoIt(item.itinerary_type, item.trip_status, this.isTransportProvider, "UA2S");
    }
    canUnableToComplete(item) {
        return this.canDoIt(item.itinerary_type, item.trip_status, this.isTransportProvider, "UA2C");
    }
    canReview(item) {
        return this.canDoIt(item.itinerary_type, item.itinerary_status, this.isTransportProvider, "REVIEW");
    }
    canEdit(item) {
        if (this.isTransportProvider) {
            return false; //this.isAllocated(item);
        }
        return this.canDoIt(item.itinerary_type, item.itinerary_status, this.isTransportProvider, "EDIT");
    }
    getCompletion(booking) {
        let tHelper = new trip_1.TripHelper();
        return tHelper.getCompletion(booking.trip_properties);
    }
    canPerformAction(bookingType, status, type, action) {
        //this.api.log("ITINERARY.canperform", { action: action, a: bookingType, b: status, c: type });
        let allowed = booking_allowed_actions_1.BOOKING_ALLOWED_ACTIONS;
        let a = allowed[bookingType];
        if (a) {
            let b = a[status.toUpperCase()];
            if (b) {
                let c = b[type.toUpperCase()];
                if (c) {
                    let actions = c['ACTIONS'];
                    if (actions) {
                        return actions.includes(action.toUpperCase());
                    }
                }
            }
        }
        return false;
    }
    allowedActionsByOperation(providerType) {
        let t = providerType.toUpperCase();
        let actionlist = booking_allowed_actions_1.BOOKING_ALLOWED_ACTIONS.ACTIONS[t];
        let res = {};
        for (let action of actionlist) {
            res[action] = { "SINGLE": { status: [] }, "ROUND": { status: [] } };
            let single = booking_allowed_actions_1.BOOKING_ALLOWED_ACTIONS.SINGLE;
            for (let statuskey of Object.keys(single)) {
                if (t in single[statuskey]) {
                    let allowedActions = single[statuskey][t]["ACTIONS"];
                    for (let allowed of allowedActions) {
                        if (allowed == action) {
                            res[action].SINGLE.status.push(statuskey);
                        }
                    }
                }
            }
            let round = booking_allowed_actions_1.BOOKING_ALLOWED_ACTIONS.ROUND;
            for (let statuskey of Object.keys(round)) {
                if (t in single[statuskey]) {
                    let allowedActions = round[statuskey][t]["ACTIONS"];
                    for (let allowed of allowedActions) {
                        if (allowed == action) {
                            res[action].ROUND.status.push(statuskey);
                        }
                    }
                }
            }
        }
        return res;
    }
    performAction(item, action, actionDisplay, payload, showReason, reason) {
        return new Promise((resolve, reject) => {
            let msg = "Are you sure you want to <b>" +
                actionDisplay.toLowerCase() +
                "</b> booking<br/><br/>Reference:<strong>" +
                item.itinerary_name +
                "</strong>?";
            let sreason = showReason ? showReason : false;
            dialogs_1.instance.confirm(actionDisplay + " Booking", msg, sreason)
                .then((r) => {
                if (sreason ? r.response : r) {
                    if (sreason) {
                        payload.reason = reason ? reason : r.reason;
                    }
                    this.api
                        .operation("itinerary." + action, payload)
                        .then((result) => {
                        resolve({ confirmation: true, response: result });
                    })
                        .catch((error) => {
                        this.api.log("ITINERARYHELPER.onperformaction", error.message);
                        dialogs_1.instance.alert("Error performing " + actionDisplay, error.message);
                        reject(error);
                    });
                }
                else {
                    resolve({ confirmation: false, response: null });
                }
            });
        });
    }
    addTrip(item, trip_id, trip) {
        let payload = { trip_id: trip_id, trip: trip };
        return this.performAction(item, "add_trip", "Add leg to trip", payload, false);
    }
    resubmit(item, offer_to, exclusive) {
        item.offer_to = offer_to;
        item.exclusive = exclusive;
        item.batch_no = item.trip_batch_no ? item.trip_batch_no : 1;
        return this.performAction(item, "resubmit", "Resubmit", item, false);
    }
    cancel(item, reason) {
        let payload = {
            itinerary_id: item.id,
            batch_no: item.trip_batch_no
        };
        return this.performAction(item, "cancel", "Cancel", payload, true, reason);
    }
    accept(item) {
        let payload = {
            itinerary_id: item.id,
            batch_no: item.trip_batch_no
        };
        return this.performAction(item, "accept", "Accept", payload, false);
    }
    decline(item, reason) {
        let payload = {
            itinerary_id: item.id,
            batch_no: item.trip_batch_no
        };
        return this.performAction(item, "decline", "Decline", payload, true, reason);
    }
    ua2s(item, reason) {
        let payload = {
            itinerary_id: item.id,
            batch_no: item.trip_batch_no
        };
        return this.performAction(item, "unable_to_service", "Unable to service", payload, true, reason);
    }
    ua2c(item) {
        return new Promise((resolve, reject) => {
            if (item.type == itinerary_type_1.ITINERARY_TYPE.SINGLE) {
                let tHelper = new trip_1.TripHelper();
                tHelper.unableToComplete(item).then(result => {
                    resolve(result);
                }).catch(e => {
                    this.api.log("ITINERARYHELPER.ua2c", e);
                    dialogs_1.instance.alert("Error Performing UA2C", e.message);
                    reject(e);
                });
            }
            else {
                reject("SINGLE LEG ONLY");
            }
        });
    }
    complete(item, completion) {
        return new Promise((resolve, reject) => {
            if (item.type == itinerary_type_1.ITINERARY_TYPE.SINGLE) {
                let trip_id = item.trip_id;
                this.api.operation("trip.complete", {
                    trip_id: trip_id,
                    completion: completion,
                }).then(result => {
                    resolve({ confirmation: true, response: result });
                }).catch(e => {
                    this.api.log("ITINERARYHELPER.complete", e);
                    dialogs_1.instance.alert("Error Performing Complete", e.message);
                    reject(e);
                });
            }
            else {
                reject("SINGLE LEG ONLY");
            }
        });
    }
    addComment(item, comment) {
        let payload = {
            itinerary_id: item.itinerary_id,
            comment: comment,
            batch_no: item.trip_batch_no
        };
        return new Promise((resolve, reject) => {
            this.api.operation("itinerary.comment", payload).then(result => {
                resolve({ confirmation: true, response: result });
            }).catch(e => {
                this.api.log("ITINERARYHELPER.addComment", e);
                dialogs_1.instance.alert("Error Adding Comment", e.message);
                reject(e);
            });
        });
    }
    reviewed(payload) {
        return new Promise((resolve, reject) => {
            this.api.operation("itinerary.reviewed", payload).then(result => {
                resolve({ confirmation: true, response: result });
            }).catch(e => {
                this.api.log("ITINERARYHELPER.review", e);
                dialogs_1.instance.alert("Error Performing Review ", e.message);
                reject(e);
            });
        });
    }
    hasPendingReview(properties) {
        if (this.isTransportProvider) {
            return this.api.isTrue(properties.batch_transporter_review);
        }
        return this.api.isTrue(properties.batch_originator_review);
    }
    maybeReview(item) {
        return new Promise((resolve, reject) => {
            if (this.hasPendingReview(item.trip_properties)) {
                let payload = {
                    itinerary_id: item.id,
                    batch_no: item.trip_batch_no
                };
                this.reviewed(payload).then(result => {
                    resolve({ confirmation: true, response: result });
                });
            }
            else {
                resolve({ confirmation: false, response: null });
            }
        });
    }
    readAllForTransporter(start, limit, filters) {
        let pagination = new utility_1.Pagination("trip_pick_up_dt");
        pagination.params.push(this.api.activeCompanyID);
        if (filters) {
            for (let filter of filters) {
                pagination.setFilter(filter.column, filter.value, filter.operator);
            }
        }
        let options = pagination.getRequestOptions(start, limit);
        return this.api.queryPaginated("itinerary.by_provider", options);
    }
    search(start, limit, filters) {
        let pagination = new utility_1.Pagination("trip_pick_up_dt");
        if (filters) {
            for (let filter of filters) {
                pagination.setFilter(filter.column, filter.value, filter.operator);
            }
        }
        let options = pagination.getRequestOptions(start, limit);
        return this.api.queryPaginated("itinerary.search", options);
    }
    read(itinerary_id, batch_no) {
        return new Promise((resolve, reject) => {
            let batchNo = batch_no ? batch_no : 1;
            let filter = [{ column: "itinerary_id", value: [itinerary_id], operator: "=" },
                { column: "trip_batch_no", value: [batchNo], operator: "=" }];
            if (this.isTransportProvider) {
                this.readAllForTransporter(0, 2, filter).then(page => {
                    if (page.data.length == 1) {
                        let item = this.helper.ObjectClone(new itinerary_1.Itinerary(), page.data[0]);
                        resolve(item);
                    }
                    else {
                        this.api.log("ITINERARYHELPER.read.invalidcuont", filter);
                        resolve(null);
                    }
                }).catch(error => {
                    dialogs_1.instance.alert("Error: Transporter read of itinerary : " + itinerary_id, error.message);
                    reject(error);
                });
            }
            else {
                return this.search(0, 2, filter).then(page => {
                    if (page.data.length == 1) {
                        let item = this.helper.ObjectClone(new itinerary_1.Itinerary(), page.data[0]);
                        resolve(item);
                    }
                    else {
                        this.api.log("ITINERARYHELPER.read.invalidcuont", filter);
                        resolve(null);
                    }
                });
            }
        });
    }
    readAll(start, limit, filters) {
        if (this.isTransportProvider) {
            return new Promise((resolve, reject) => {
                this.readAllForTransporter(start, limit, filters).then(page => {
                    page.data = page.data.map((i) => {
                        return this.helper.ObjectClone(new itinerary_1.Itinerary(), i);
                    });
                    resolve(page);
                }).catch(error => {
                    reject(error);
                });
            });
        }
        else {
            return itinerary_1.itineraryservice.readAll(new itinerary_1.Itinerary(), filters);
        }
    }
    allActivityCarer(limit, filters) {
        return new Promise((resolve, reject) => {
            let pagination = new utility_1.Pagination("trip_log_id");
            pagination.sortBy.descending = true;
            if (filters) {
                for (let filter of filters) {
                    pagination.setFilter(filter.column, filter.value, filter.operator);
                }
            }
            let options = pagination.getRequestOptions(0, limit);
            this.api
                .queryPaginated("trip_activity_log_by_company", options)
                .then((page) => {
                resolve(this.processActivityLogRows(page.data));
            })
                .catch((e) => {
                this.api.log("API.allActivityCarer.error", e);
                reject(e);
            });
        });
    }
    allActivityTransporter(limit, filters) {
        return new Promise((resolve, reject) => {
            let pagination = new utility_1.Pagination("trip_log_id");
            pagination.sortBy.descending = true;
            pagination.params.push(this.api.activeCompanyID);
            if (filters) {
                for (let filter of filters) {
                    pagination.setFilter(filter.column, filter.value, filter.operator);
                }
            }
            let options = pagination.getRequestOptions(0, limit);
            this.api
                .queryPaginated("trip_activity_log_by_provider", options)
                .then((page) => {
                resolve(this.processActivityLogRows(page.data));
            })
                .catch((e) => {
                this.api.log("API.allActivityTransporter.error", e);
                reject(e);
            });
        });
    }
    allActivity(limit, filters) {
        if (this.isTransportProvider) {
            return this.allActivityTransporter(limit, filters);
        }
        return this.allActivityCarer(limit, filters);
    }
    processActivityLogRows(rows) {
        return rows.map((item) => {
            item.dt = this.api.ts2dt(item.trip_log_created);
            item.company = item.trip_log_company_name;
            item.user = item.trip_log_identity_name;
            item.event_entity = item.trip_log_event_entity;
            item.expanded = false;
            item.event = item.trip_log_type;
            item.status = item.trip_log_status;
            item.offer_tier = item.trip_log_trip_offer_tier;
            item.ux = this.getEventUX(item);
            log_1.TripLogHelper.processLogComments(item);
            return item;
        });
    }
    ;
    activityLogCarer(itinerary_id, filters) {
        return new Promise((resolve, reject) => {
            let pagination = new utility_1.Pagination("trip_log_id");
            pagination.sortBy.descending = true;
            pagination.params.push(itinerary_id);
            if (filters) {
                for (let filter of filters) {
                    pagination.setFilter(filter.column, filter.value, filter.operator);
                }
            }
            let options = pagination.getRequestOptions(0, 100);
            this.api
                .queryPaginated("trip_log.by_itinerary", options)
                .then((res) => {
                resolve(this.processActivityLogRows(res.data));
            }).catch(e => {
                this.api.log("API.activityLogCarer.error", e);
                reject(e);
            });
        });
    }
    activityLogTransporter(itinerary_id, filters) {
        return new Promise((resolve, reject) => {
            let pagination = new utility_1.Pagination("trip_log_id");
            pagination.sortBy.descending = true;
            pagination.params.push(this.api.activeCompanyID);
            pagination.params.push(itinerary_id);
            if (filters) {
                for (let filter of filters) {
                    pagination.setFilter(filter.column, filter.value, filter.operator);
                }
            }
            let options = pagination.getRequestOptions(0, 100);
            this.api
                .queryPaginated("provider_trip_log.by_itinerary", options)
                .then((res) => {
                resolve(this.processActivityLogRows(res.data));
            }).catch(e => {
                this.api.log("API.activityLogCarer.error", { options: options, error: e.message });
                reject(e);
            });
        });
    }
    activityLog(itinerary_id, filters) {
        if (this.isTransportProvider) {
            return this.activityLogTransporter(itinerary_id, filters);
        }
        return this.activityLogCarer(itinerary_id, filters);
    }
    filterCounts(prefix, field, pagination) {
        return new Promise((resolve, reject) => {
            //Get unfiltered list to get all the values
            let items = [];
            let p = new utility_1.Pagination(field);
            p.params = pagination.params;
            let opts = p.getRequestOptions(0, 100);
            opts.order_by = {};
            let existingFilter = this.helper.getArrayItem(pagination.filters, "column", field);
            this.api.queryPaginated(prefix + field, opts).then(page => {
                items = page.data.map((o) => {
                    let key = o[field];
                    o.selected = existingFilter ? existingFilter.values.includes(key) : false;
                    o.filtered_count = 0;
                    return o;
                });
                resolve(items);
                //
                //Now lets let the counts based on filters
                //
                /*
                let options = pagination.getRequestOptions(0, 25);
                options.order_by = {};
                this.api.queryPaginated(prefix + field, options).then(result => {
                    for (let i of result.data) {
                        let key = i[field];
                        let res = this.helper.getArrayItem(items, field, key);
                        if (res) {
                            res.filtered_count = i.count;
                        }
                    }
                    resolve(items);
                }).catch(error => {
                    reject(error);
                });
                */
            }).catch(error => {
                reject(error);
            });
        });
    }
    statusChip(item) {
        let ux = this.statusUX(item.itinerary_status);
        if (this.isVipOffer(item) && this.isOffered(item)) {
            return ux.vip;
        }
        return ux;
    }
}
exports.ItineraryHelper = ItineraryHelper;
//# sourceMappingURL=itinerary.js.map