"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LegBase = void 0;
const api_1 = require("../api");
const helper_1 = require("../helper");
const lov_1 = require("./lov");
const trip_status_1 = require("../const/trip_status");
const trip_states_1 = require("../const/trip_states");
const ux_1 = require("./ux");
const address_1 = require("../model/nested/address");
const datetime_1 = require("../model/nested/datetime");
//Base for trip and itinerary helper
class LegBase {
    constructor() {
        this.api = api_1.Api.instance();
        this.helper = helper_1.Helper.instance();
        this.calltypes = [];
        this.priorities = [];
        this.variables = [];
        this.isTransportProvider = false;
        let b = this.api.activeCompany ? this.api.isTrue(this.api.activeCompany.company_type_properties.transport_provider) : false;
        this.isTransportProvider = b;
    }
    get TRIP_STATUS() {
        return trip_status_1.TRIP_STATUS;
    }
    get TRIP_STATES() {
        return trip_states_1.TRIP_STATES;
    }
    getState(seconds, status) {
        let res = this.TRIP_STATES.OK;
        if (status == this.TRIP_STATUS.ACCEPTING) {
            res = this.TRIP_STATES.API_ERROR;
        }
        else if ((status == this.TRIP_STATUS.ACCEPTED) &&
            (((seconds / 60) > -60) && (seconds / 60) < 15)) {
            res = this.TRIP_STATES.IN_PROGRESS;
        }
        else if ((status == this.TRIP_STATUS.OFFERED || status == this.TRIP_STATUS.UNFULFILLED) &&
            (seconds < 0)) {
            res = this.TRIP_STATES.OVERDUE;
        }
        else if ((status != this.TRIP_STATUS.COMPLETED &&
            status != this.TRIP_STATUS.CANCELLED &&
            status != this.TRIP_STATUS.FAILED) &&
            (seconds < 0)) {
            res = this.TRIP_STATES.LATE;
        }
        return res;
    }
    refreshCallTypes(params) {
        return new Promise((resolve, reject) => {
            lov_1.LovHelper.callTypesAlias(params).then(result => {
                this.calltypes = result;
                resolve(true);
            }).catch(e => {
                this.api.log("refreshCallTypes.error %o", e);
                reject(false);
            });
        });
    }
    refreshPriorities(params) {
        return new Promise((resolve, reject) => {
            lov_1.LovHelper.prioritiesAlias(params).then(result => {
                this.priorities = result;
                resolve(true);
            }).catch(e => {
                this.api.log("refreshPriorities.error %o", e);
                reject(false);
            });
        });
    }
    refreshVariables(params) {
        return new Promise((resolve, reject) => {
            lov_1.LovHelper.variablesAlias(params).then(result => {
                this.variables = result;
                resolve(true);
            }).catch(e => {
                this.api.log("refreshVariables.error %o", e);
                reject(false);
            });
        });
    }
    statusUX(status) {
        return ux_1.UXHelper.statusUX(status);
    }
    statusColor(status) {
        return ux_1.UXHelper.statusColor(status);
    }
    statusOutline(status) {
        return ux_1.UXHelper.statusOutline(status);
    }
    statusDark(status) {
        return ux_1.UXHelper.statusDark(status);
    }
    getEventUX(item) {
        return ux_1.UXHelper.getEventUX(item);
    }
    copyDestination(target, source, includeDT) {
        target.is_facility = source.is_facility;
        target.facility_id = source.facility_id;
        target.facility_notes = source.facility_notes;
        target.address = this.helper.ObjectClone(new address_1.Address(), source.address);
        if (includeDT) {
            target.dt = this.helper.ObjectClone(new datetime_1.DateTime(), source.dt);
        }
    }
}
exports.LegBase = LegBase;
//# sourceMappingURL=legbase.js.map