"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TripLogHelper = void 0;
const helper_1 = require("../helper");
class TripLogHelper {
    static processLogComments(item) {
        let helper = helper_1.Helper.instance();
        try {
            item.comment = item.trip_log_comment
                ? JSON.parse(item.trip_log_comment)
                : item.comment;
            // Clear the  message
            item.message = null;
            //set message to user comment
            if (item.comment && item.event == "COMMENT") {
                if (Array.isArray(item.comment.comments)) {
                    item.message = { first: item.comment.comments[0], all: [] };
                }
                else {
                    item.message = { first: item.comment, all: [] };
                }
            }
            else if (item.comment && item.event == "EDIT") {
                item.edits_raw = item.comment.edits
                    .map((str) => {
                    if (typeof str === 'string' || str instanceof String) {
                        return JSON.parse(str);
                    }
                    else {
                        return str;
                    }
                })
                    .filter((f) => !f.path.includes("route_summary") &&
                    !f.path.includes("_id") &&
                    !f.path.includes("/modified") &&
                    !f.path.includes("/created") &&
                    !f.path.includes("details/pricing") &&
                    !f.path.includes("/dt/epoch") &&
                    !f.path.includes("/properties/display") &&
                    !f.path.includes("lov/code") &&
                    !f.path.includes("originator_review") &&
                    !f.path.includes("transporter_review"));
                item.edits = {};
                for (let e of item.edits_raw) {
                    let path = e.path.replaceAll("/", " ").trim();
                    let label = path.replaceAll("_", " ").replaceAll(" dt ", " ");
                    if (e.op == "ADDED") {
                        let o = item.edits[path];
                        if (o) {
                            o.new = e.value;
                        }
                        else {
                            item.edits[path] = { label: label, new: e.value, old: "" };
                        }
                    }
                    else {
                        let o = item.edits[path];
                        if (o) {
                            o.old = e.value;
                        }
                        else {
                            item.edits[path] = { label: label, old: e.value, new: "" };
                        }
                    }
                }
            }
            else if (item.comment) {
                let a = [];
                if (item.comment.comments && item.comment.comments.length > 0) {
                    for (let c of item.comment.comments) {
                        a.push(c);
                    }
                }
                if (item.comment.audits && item.comment.audits.length > 0) {
                    for (let cmt of item.comment.audits) {
                        //sometimes we get audits[null]
                        if (cmt) {
                            if (typeof cmt == 'object') {
                                for (const [key, value] of Object.entries(cmt)) {
                                    a.push(key + ":" + value);
                                }
                            }
                            else {
                                a.push(cmt);
                            }
                        }
                    }
                }
                item.server_comments = a;
                if (a.length > 0) {
                    item.message = { first: item.server_comments[0], all: item.server_comments };
                }
            }
        }
        catch (e) {
            console.log("TripLogHelper.processLogComments", {
                a: item,
                b: e,
            });
        }
    }
}
exports.TripLogHelper = TripLogHelper;
//# sourceMappingURL=log.js.map