"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.instance = exports.PermissionsHelper = void 0;
const api_1 = require("../api");
const helper_1 = require("../helper");
class MenuStates {
    constructor() {
        this.users = { permission: "internal_user.create", show: true };
        this.markets = { permission: "market.readall", show: true };
        this.marketRules = { permission: "market_rule.readall", show: true };
        this.contracts = { permission: "contract.readall", show: true };
        this.facilities = { permission: "facility.readall", show: true };
        this.bookings = { permission: "itinerary.readall", show: true };
        this.trips = { permission: "itinerary.read", show: true };
        this.lookUpDate = { permission: "lov_alias.readall", show: true };
    }
}
class PermissionsHelper {
    constructor() {
        this.api = api_1.Api.instance();
        this.helper = helper_1.Helper.instance();
        this.roles = null;
        this.menus = new MenuStates();
    }
    static instance() {
        return exports.instance;
    }
    roleCheck(role) {
        return this.roles ?
            this.roles.filter((p) => { return p.role_name == role; }).length > 0
            : false;
    }
    refreshStates() {
        Object.keys(this.menus).forEach(key => {
            let menu = this.menus[key];
            menu.show = this.roleCheck(menu.permission);
        });
    }
    get grantedRoles() {
        if (!this.roles) {
            let p = this.api.sessionStorage.getItem('grantedRoles');
            if (p) {
                this.roles = JSON.parse(p);
            }
        }
        return this.roles;
    }
    set grantedRoles(roles) {
        this.api.sessionStorage.setItem('grantedRoles', JSON.stringify(roles));
    }
    refreshPermissionsFromDB() {
        //"identity.grantedroles"
        //identity.allowed_values
        this.roles = [];
        return this.api.operation("identity.grantedroles").then(roles => {
            this.grantedRoles = roles;
            this.refreshStates();
            return roles;
        });
    }
}
exports.PermissionsHelper = PermissionsHelper;
exports.instance = new PermissionsHelper();
//# sourceMappingURL=permissions.js.map