"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PreferencesHelper = void 0;
const helper_1 = require("../helper");
const api_1 = require("../api");
const utility_1 = require("../utility");
class PreferencesHelper {
    constructor(name, headers, pagination) {
        this.api = api_1.Api.instance();
        this.helper = helper_1.Helper.instance();
        this.headers = null;
        this.pagination = null;
        this.gridkey = null;
        this.paginationDefaultSortColumn = null;
        this.gridkey = name;
        this.headers = headers;
        this.pagination = pagination;
        this.paginationDefaultSortColumn = pagination.defaultSortColumn;
    }
    updateHeadersFromPreferences(list) {
        if (this.headers) {
            let props = [
                { key: "show", default: true },
                { key: "position", default: list.length },
            ];
            return this.helper.updateArrayFromArray(this.headers, list, "text", props);
        }
        throw new Error('Headers property not set');
    }
    onGridColumnPreferencesChange(list) {
        let props = [
            { key: "show", default: true },
            { key: "position", default: list.length },
        ];
        this.headers = this.helper.updateArrayFromArray(this.headers, list, "text", props);
        this.saveGridPreferences();
        return this.headers;
    }
    initializeGridPreferences(preferences) {
        let prefs = preferences ? preferences : this.api.userPreferences;
        if (prefs.grids && (this.gridkey in prefs.grids)) {
            let cols = prefs.grids[this.gridkey].headers;
            if (cols) {
                this.headers = this.updateHeadersFromPreferences(cols);
            }
            let p = prefs.grids[this.gridkey].pagination;
            if (!this.paginationDefaultSortColumn) {
                throw new Error('paginationDefaultSortColumn property not set');
            }
            if (p && Object.keys(p).length > 0) {
                this.pagination = this.helper.ObjectClone(new utility_1.Pagination(this.paginationDefaultSortColumn), p);
            }
            else {
                this.pagination = new utility_1.Pagination(this.paginationDefaultSortColumn);
            }
            this.pagination.loading = false;
        }
    }
    saveGridPreferences() {
        if (!this.gridkey) {
            throw new Error('gridkey property not set');
        }
        if (!this.headers) {
            throw new Error('headers property not set');
        }
        if (!this.pagination) {
            throw new Error('pagination property not set');
        }
        let prefs = this.api.userPreferences;
        if (!prefs.grids) {
            prefs.grids = {};
        }
        let x = this.pagination;
        prefs.grids[this.gridkey.toLowerCase()] = {
            headers: this.headers,
            pagination: x,
        };
        this.api.userPreferences = prefs;
    }
}
exports.PreferencesHelper = PreferencesHelper;
//# sourceMappingURL=preferences.js.map