"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TripHelper = void 0;
const leg_allowed_actions_1 = require("../const/leg_allowed_actions");
const trip_status_1 = require("../const/trip_status");
const completion_1 = require("../model/nested/completion");
const helper_1 = require("../helper");
const datetime_1 = require("../model/nested/datetime");
const trip_1 = require("../model/trip");
const legbase_1 = require("./legbase");
const utility_1 = require("../utility");
const dialogs_1 = require("../dialogs");
const appointment_types_1 = require("../const/appointment_types");
const itinerary_type_1 = require("../const/itinerary_type");
class TripHelper extends legbase_1.LegBase {
    constructor() {
        super();
    }
    //
    performAction(leg, action, actionDisplay, reason) {
        return new Promise((resolve, reject) => {
            let msg = "Are you sure you want to <b>" +
                actionDisplay.toLowerCase() +
                "</b> booking<br/><br/>Reference:<strong>" +
                leg.trip_name +
                "</strong>?";
            let showReason = action != "accept";
            dialogs_1.instance.confirm(actionDisplay + " Trip", msg, showReason)
                .then((r) => {
                if (showReason ? r.response : r) {
                    this.api
                        .operation("trip." + action, {
                        trip_id: leg.trip_id,
                        reason: reason ? reason : r.reason,
                    })
                        .then((result) => {
                        resolve({ confirmation: true, response: result });
                    })
                        .catch((error) => {
                        this.api.log("TRIPHELPER.onperformaction", error);
                        dialogs_1.instance.alert("Error performing " + actionDisplay, error.message);
                        reject(error);
                    });
                }
                else {
                    resolve({ confirmation: false, response: null });
                }
            });
        });
    }
    review(trip_id) {
        return new Promise((resolve, reject) => {
            this.api
                .operation("trip.reviewed", {
                trip_id: trip_id
            })
                .then((result) => {
                resolve({ confirmation: true, response: result });
            })
                .catch((error) => {
                this.api.log("TRIPHELPER.review", error);
                dialogs_1.instance.alert("Error Performing Review ", error.message);
                reject(error);
            });
        });
    }
    resubmit(item, offer_to, exclusive) {
        return new Promise((resolve, reject) => {
            item.offer_to = offer_to;
            item.exclusive = exclusive;
            this.api.operation("trip.resubmit", item).then(result => {
                resolve({ confirmation: true, response: result });
            }).catch((error) => {
                this.api.log("TRIPHELPER.resubmit", error);
                dialogs_1.instance.alert("Error Performing Resumbit", error.message);
                reject(error);
            });
        });
    }
    tripPendingReview(leg) {
        if (this.isTransportProvider) {
            return this.api.isTrue(leg.properties.transporter_review);
        }
        return this.api.isTrue(leg.properties.originator_review);
    }
    hasPendingReview(properties) {
        if (this.isTransportProvider) {
            return this.api.isTrue(properties.transporter_review);
        }
        return this.api.isTrue(properties.originator_review);
    }
    maybeReview(leg) {
        return new Promise((resolve, reject) => {
            if (this.hasPendingReview(leg.properties)) {
                this.review(leg.trip_id).then(result => {
                    resolve({ confirmation: true, response: result });
                });
            }
            else {
                resolve({ confirmation: false, response: null });
            }
        });
    }
    accept(leg) {
        return this.performAction(leg, "accept", "Accept");
    }
    decline(leg, reason) {
        return this.performAction(leg, "decline", "Decline", reason);
    }
    cancel(leg, reason) {
        return this.performAction(leg, "cancel", "Cancel", reason);
    }
    unableToService(leg, reason) {
        return this.performAction(leg, "unable_to_service", "Unable to service", reason);
    }
    unableToComplete(leg, reason) {
        return this.performAction(leg, "unable_to_complete", "Cancel in progress", reason);
    }
    pickUpDisplay(trip) {
        if (trip.trip_is_return && (trip.trip_return_pick_up_type != appointment_types_1.APPOINTMENT_PICKUP_TYPE.SETTIME)) {
            return trip.trip_pick_up_date != '' ? this.api.fmtDate(trip.trip_pick_up_date, this.api.dateAppFormat) + ' ' + trip.trip_return_pick_up_type : trip.trip_return_pick_up_type;
        }
        return this.api.fmtDT(trip.trip_pick_up_dt);
    }
    addComment(trip_id, comment) {
        let payload = {
            trip_id: trip_id,
            comment: comment,
        };
        return new Promise((resolve, reject) => {
            this.api.operation("trip.comment", payload).then(result => {
                resolve({ confirmation: true, response: result });
            }).catch(e => {
                this.api.log("TRIPHELPER.addComment", e);
                dialogs_1.instance.alert("Error Adding Comment", e.message);
                reject(e);
            });
        });
    }
    isOneWay(trip) {
        return trip.trip_type == itinerary_type_1.ITINERARY_TYPE.SINGLE;
    }
    isRoundTrip(trip) {
        return trip.trip_type == itinerary_type_1.ITINERARY_TYPE.ROUND;
    }
    isMultiLeg(trip) {
        return trip.trip_type == itinerary_type_1.ITINERARY_TYPE.MULTI;
    }
    isFailed(trip) {
        return trip.trip_status == trip_status_1.TRIP_STATUS.FAILED;
    }
    isExpired(trip) {
        return trip.trip_status == trip_status_1.TRIP_STATUS.EXPIRED;
    }
    isUnfulfilled(trip) {
        return trip.trip_status == trip_status_1.TRIP_STATUS.UNFULFILLED;
    }
    isBlocked(trip) {
        return this.isFailed(trip) || this.isExpired(trip) || this.isUnfulfilled(trip);
    }
    isCancelled(trip) {
        return trip.trip_status == trip_status_1.TRIP_STATUS.CANCELLED;
    }
    isCompleted(trip) {
        return trip.trip_status == trip_status_1.TRIP_STATUS.COMPLETED;
    }
    isFinalState(trip) {
        return this.isCompleted(trip) || this.isCancelled(trip);
    }
    isOffered(leg) {
        return leg.trip_status == trip_status_1.TRIP_STATUS.OFFERED;
    }
    isAccepted(leg) {
        return leg.trip_status == trip_status_1.TRIP_STATUS.ACCEPTED;
    }
    isAccepting(leg) {
        return leg.trip_status == trip_status_1.TRIP_STATUS.ACCEPTING;
    }
    isVipOffer(item) {
        if (item.properties && item.properties.offer) {
            return item.properties.offer.tier == -1;
        }
        else if (item.trip_offer_tier) {
            return item.trip_offer_tier == -1 || item.trip_offer_tier == "vip";
        }
        return false;
    }
    canAccept(leg) {
        return this.canDoIt(leg, this.isTransportProvider, 'ACCEPT');
    }
    canResubmit(leg) {
        return this.canDoIt(leg, this.isTransportProvider, 'RESUBMIT');
    }
    canDecline(leg) {
        return this.canDoIt(leg, this.isTransportProvider, 'DECLINE');
    }
    canCancel(leg) {
        return this.canDoIt(leg, this.isTransportProvider, 'CANCEL');
    }
    canRate(leg) {
        return this.canDoIt(leg, this.isTransportProvider, 'RATE');
    }
    canComplete(leg) {
        let diff = this.api.dayjs.tz(leg.trip_pick_up_dt).diff(this.api.now, "second");
        return diff < 0 && this.canDoIt(leg, this.isTransportProvider, 'COMPLETE');
    }
    canDoIt(leg, isTransportProvider, action) {
        let status = leg.trip_status.toUpperCase();
        //If leader value is set then, this is not a leader leg
        let legtype = leg.trip_leader ? "OTHER" : "A";
        let providerType = isTransportProvider ? "DISPATCH" : "CARER";
        return this.canPerformAction(legtype, status, providerType, action);
    }
    canUnableToService(leg) {
        return this.canDoIt(leg, this.isTransportProvider, 'UA2S');
    }
    canUnableToComplete(leg) {
        return this.canDoIt(leg, this.isTransportProvider, 'UA2C');
    }
    canEdit(leg) {
        return this.canDoIt(leg, this.isTransportProvider, 'EDIT');
    }
    canReview(leg) {
        return this.canDoIt(leg, this.isTransportProvider, 'REVIEW');
    }
    isReturnLeg(leg) {
        return leg.properties.appointment_pick_up_type;
    }
    canPerformAction(leg, status, type, action) {
        let allowed = leg_allowed_actions_1.LEG_ALLOWED_ACTIONS;
        let a = allowed[leg];
        if (a) {
            let b = a[status.toUpperCase()];
            if (b) {
                let c = b[type.toUpperCase()];
                if (c) {
                    let actions = c['ACTIONS'];
                    if (actions) {
                        return actions.includes(action.toUpperCase());
                    }
                }
            }
        }
        return false;
    }
    needsReview(leg) {
        if (this.isTransportProvider) {
            return leg.properties.transporter_review;
        }
        return leg.properties.originator_review;
    }
    getCompletion(properties) {
        let completion = new completion_1.Completion();
        let helper = helper_1.Helper.instance();
        let pickUp = helper.ObjectClone(new datetime_1.DateTime(), properties.pick_up.dt);
        completion.on_scene_dt = helper.ObjectClone(new datetime_1.DateTime(), properties.pick_up.dt);
        completion.at_destination_dt = helper.ObjectClone(new datetime_1.DateTime(), properties.pick_up.dt);
        completion.clear_dt = helper.ObjectClone(new datetime_1.DateTime(), properties.pick_up.dt);
        let d = this.api.now.format(this.api.DTFormat);
        completion.clear_dt.datetime = d;
        //this.api.log("GETCOMPLETTION.1", d);
        let x = properties.route_summary;
        completion.total_distance = x.distance;
        completion.total_distance_unit = x.distance_unit;
        return completion;
    }
    setDispatchVariables(leg) {
        return new Promise((resolve, reject) => {
            Promise.all([this.refreshCallTypes(),
                this.refreshPriorities(),
                this.refreshVariables()]).then(res => {
                this.api.operation("trip.set_variables", leg).then((res) => {
                    leg.properties.priority_lov_id = res.properties.priority_lov_id;
                    let item = this.helper.getArrayItem(this.priorities, "lov_alias_lov_id", res.properties.priority_lov_id);
                    let jd = leg.properties.details;
                    if (item) {
                        jd.addPriority(item);
                    }
                    let vars = this.helper.getArrayItems(this.variables, "lov_alias_lov_id", res.properties.dispatch_variables_lov_id);
                    if (vars) {
                        vars.forEach((lov) => {
                            jd.addVariable(lov);
                        });
                    }
                    resolve(leg);
                }).catch(e => {
                    reject(e);
                });
            }).catch(e => {
                reject(e);
            });
        });
    }
    updateTripPropsFromDetail(trip) {
        trip.properties.type_lov_id =
            trip.properties.details.types.length > 0
                ? trip.properties.details.types[0].lov_alias_lov_id
                : -1;
        //Don't update the dispatch priority if this is a return leg
        if (!trip.trip_is_return) {
            trip.properties.priority_lov_id =
                trip.properties.details.priorities.length > 0
                    ? trip.properties.details.priorities[0].lov_alias_lov_id
                    : -1;
        }
        trip.properties.variables = trip.properties.details.nonDispatchVariables;
    }
    copyDispatchDetails(leg, trip) {
        this.updateTripPropsFromDetail(trip);
        leg.trip_itinerary_id = trip.trip_itinerary_id;
        leg.itinerary_market_id = trip.itinerary_market_id;
        leg.properties.route_summary = this.helper.ObjectClone(leg.properties.route_summary, trip.properties.route_summary);
        leg.properties.pick_up = this.helper.ObjectClone(leg.properties.pick_up, trip.properties.pick_up);
        leg.properties.drop_off = this.helper.ObjectClone(leg.properties.drop_off, trip.properties.drop_off);
        leg.properties.type_lov_id = trip.properties.type_lov_id;
        leg.properties.priority_lov_id = trip.properties.priority_lov_id;
        leg.properties.variables = trip.properties.details.nonDispatchVariables;
        leg.properties.details = this.helper.ObjectClone(leg.properties.details, trip.properties.details);
        return leg;
    }
    itineraryTripsForTransporter(itinerary_id, start, limit, filters) {
        let pagination = new utility_1.Pagination("trip_id");
        pagination.params.push(this.api.activeCompanyID);
        pagination.params.push(itinerary_id);
        if (filters) {
            for (let filter of filters) {
                pagination.setFilter(filter.column, filter.value, filter.operator);
            }
        }
        let options = pagination.getRequestOptions(start, limit);
        return this.api.queryPaginated("itinerary_trips_by_provider", options);
    }
    tripForTransporter(trip_id) {
        return new Promise((resolve, reject) => {
            let pagination = new utility_1.Pagination("trip_id");
            pagination.params.push(this.api.activeCompanyID);
            pagination.params.push(trip_id);
            let options = pagination.getRequestOptions(0, 10);
            this.api.queryPaginated("trip.by_provider", options).then(result => {
                if (result.data.length == 1) {
                    let trip = this.helper.ObjectClone(new trip_1.Trip(), result.data[0]);
                    resolve(trip);
                }
                else {
                    this.api.log("TRIPHELPER.read.notfound", trip_id);
                    resolve(null);
                }
            }).catch(error => {
                reject(error);
            });
        });
    }
    itineraryTripsForCarer(itinerary_id, start, limit, filters) {
        let pagination = new utility_1.Pagination("trip_id");
        pagination.setFilter("trip_itinerary_id", [itinerary_id], "=");
        if (filters) {
            for (let filter of filters) {
                pagination.setFilter(filter.column, filter.value, filter.operator);
            }
        }
        let options = pagination.getRequestOptions(start, limit);
        return this.api.operation("trip.search", options);
    }
    read(trip_id) {
        if (this.isTransportProvider) {
            return this.tripForTransporter(trip_id);
        }
        else {
            let pagination = new utility_1.Pagination("trip_id");
            pagination.setFilter("trip_id", [trip_id], "=");
            let options = pagination.getRequestOptions(0, 1);
            return new Promise((resolve, reject) => {
                this.api.operation("trip.search", options).then(page => {
                    if (page.data.length > 0) {
                        let trip = this.helper.ObjectClone(new trip_1.Trip(), page.data[0]);
                        resolve(trip);
                    }
                    else {
                        resolve(null);
                    }
                }).catch(e => {
                    reject(e);
                });
            });
        }
    }
    readAll(itinerary_id, start, limit, filters) {
        if (this.isTransportProvider) {
            return new Promise((resolve, reject) => {
                this.itineraryTripsForTransporter(itinerary_id, start, limit, filters).then(page => {
                    page.data = page.data.map((i) => {
                        return this.helper.ObjectClone(new trip_1.Trip(), i);
                    });
                    resolve(page);
                }).catch(error => {
                    reject(error);
                });
            });
        }
        else {
            return this.itineraryTripsForCarer(itinerary_id, start, limit, filters);
        }
    }
    transporterJourneyLegs(trip_id) {
        return new Promise((resolve, reject) => {
            let pagination = new utility_1.Pagination("trip_id");
            pagination.params.push(trip_id);
            let options = pagination.getRequestOptions(0, 20);
            this.api.queryPaginated("provider_trip_legs", options).then(page => {
                page.data = page.data.map((i) => {
                    return this.helper.ObjectClone(new trip_1.Trip(), i);
                });
                resolve(page);
            }).catch(error => {
                this.api.log("transporterJourneyLegs.read.error", { options: options, error: error.message });
                dialogs_1.instance.alert("Error ", error.message);
                reject(error);
            });
        });
    }
    carerJourneyLegs(trip_id) {
        return new Promise((resolve, reject) => {
            let pagination = new utility_1.Pagination("trip_id");
            pagination.params.push(trip_id);
            let options = pagination.getRequestOptions(0, 20);
            this.api.queryPaginated("trip_legs", options).then(page => {
                page.data = page.data.map((i) => {
                    return this.helper.ObjectClone(new trip_1.Trip(), i);
                });
                resolve(page);
            }).catch(error => {
                this.api.log("carerJourneyLegs.read.error", { options: options, error: error.message });
                dialogs_1.instance.alert("Error ", error.message);
                reject(error);
            });
        });
    }
    journeyLegs(trip) {
        if (this.isTransportProvider) {
            return this.transporterJourneyLegs(trip);
        }
        return this.carerJourneyLegs(trip);
    }
    statusChip(item) {
        let ux = this.statusUX(item.trip_status);
        if (this.isVipOffer(item) && this.isOffered(item)) {
            return ux.vip;
        }
        else if (this.isUnfulfilled(item)) {
            ux.tooltip = item.trip_unfulfilled_reason && item.trip_unfulfilled_reason.length > 0 ? item.trip_unfulfilled_reason : "Unable to make further offers.";
        }
        else if (this.isExpired(item)) {
            ux.tooltip = item.trip_unfulfilled_reason && item.trip_unfulfilled_reason.length > 0 ? item.trip_unfulfilled_reason : "Pick up time is beyond market rule time.";
        }
        else if (this.isFailed(item)) {
            ux.tooltip = item.trip_unfulfilled_reason && item.trip_unfulfilled_reason.length > 0 ? item.trip_unfulfilled_reason : "Error creating offers.";
        }
        return ux;
    }
}
exports.TripHelper = TripHelper;
//# sourceMappingURL=trip.js.map