"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.instance = exports.ItineraryHelper = void 0;
const api_1 = require("./api");
const helper_1 = require("./helper");
const lov_alias_1 = require("./model/lovs/lov_alias");
class ItineraryHelper {
    constructor() {
        this.api = api_1.Api.instance();
        this.helper = helper_1.Helper.instance();
        this.calltypes = [];
        this.priorities = [];
        this.variables = [];
    }
    static instance() {
        return exports.instance;
    }
    getCallTypes() {
        return lov_alias_1.calltypeservicealias.readAll(lov_alias_1.Properties.instance(lov_alias_1.CALL_TYPE_ALIAS)).then(rows => {
            this.calltypes = rows;
        });
    }
    getDispatchPriorities() {
        return lov_alias_1.callpriorityservicealias.readAll(lov_alias_1.Properties.instance(lov_alias_1.CALL_PRIORITY_ALIAS)).then(rows => {
            this.priorities = rows;
        });
    }
    getVariables() {
        return lov_alias_1.losservicealias.readAll(lov_alias_1.Properties.instance(lov_alias_1.LEVEL_OF_SERVICE_ALIAS)).then(rows => {
            this.variables = rows;
        });
    }
    setDispatchVariables(itinerary) {
        return Promise.all([this.getCallTypes(), this.getDispatchPriorities(), this.getVariables()]).then(res => {
            let leg = itinerary.aLeg;
            return this.api.operation("trip.set_variables", leg).then((res) => {
                leg.properties.priority_lov_id = res.properties.priority_lov_id;
                //this.api.log("VARIABLES.0", res.properties.priority_lov_id);
                let item = this.helper.getArrayItem(this.priorities, "lov_alias_lov_id", res.properties.priority_lov_id);
                //this.api.log("VARIABLES.1", item);
                if (item) {
                    //this.api.log("VARIABLES.2", item);
                    itinerary.properties.details.addPriority(item);
                }
                this.api.log("VARIABLES.3", { a: res, b: res.properties });
                let vars = this.helper.getArrayItems(this.variables, "lov_alias_lov_id", res.properties.dispatch_variables_lov_id);
                if (vars) {
                    vars.forEach((lov) => {
                        itinerary.properties.details.addVariable(lov);
                    });
                }
                return Promise.resolve(res);
            });
        });
    }
}
exports.ItineraryHelper = ItineraryHelper;
exports.instance = new ItineraryHelper();
//# sourceMappingURL=iteneraryhelper.js.map