"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.companyservice = exports.Company = exports.NOTIFICATION_API = exports.TRIP_API = exports.FACILITY_API = exports.TRAUMASOFT = void 0;
const address_1 = require("./nested/address");
const contact_1 = require("./nested/contact");
const notification_1 = require("./notification");
const class_validator_1 = require("class-validator");
const serviceapi_1 = require("../serviceapi");
const avatar_1 = require("./nested/avatar");
//import {CompanyTypeProperties} from "~/plugins/model/lov/company_type";
exports.TRAUMASOFT = "Traumasoft";
exports.FACILITY_API = "facility_api";
exports.TRIP_API = "trip_api";
exports.NOTIFICATION_API = "notification_api";
class Company {
    constructor() {
        // Important !! so server knows what type this is
        this.entity_type = 'company';
        this.company_id = undefined;
        this.company_name = '';
        this.company_type = '';
        this.created = undefined;
        this.deleted = undefined;
        this.modified = undefined;
        this.properties = new Company.Properties();
    }
    upgrade() {
        if (Array.isArray(this.properties.integrations)) {
            this.properties.integrations = {};
            this.properties.setIntegrationDefaults();
        }
    }
    get id() {
        return this.company_id;
    }
    set id(value) {
        this.company_id = value;
    }
    get name() {
        return this.company_name;
    }
    set name(value) {
        this.company_name = value;
    }
    get type() {
        return this.company_type;
    }
    set type(value) {
        this.company_type = value;
    }
    get domain() {
        return this.properties.domain || '';
    }
    set domain(value) {
        this.properties.domain = value;
        this.setAvatar();
    }
    get facilityApi() {
        return this.properties.integrations[exports.FACILITY_API] || {};
    }
    set facilityApi(value) {
        this.properties.integrations[exports.FACILITY_API] = value;
    }
    get tripApi() {
        return this.properties.integrations[exports.TRIP_API] || {};
    }
    set tripApi(value) {
        this.properties.integrations[exports.TRIP_API] = value;
    }
    get notificationApi() {
        return this.properties.integrations[exports.NOTIFICATION_API] || {};
    }
    set notificationApi(value) {
        this.properties.integrations[exports.NOTIFICATION_API] = value;
    }
    setAvatar() {
        this.properties.avatar.label = this.domain.substring(0, 3).toUpperCase();
    }
}
__decorate([
    class_validator_1.MaxLength(100)
], Company.prototype, "company_name", void 0);
__decorate([
    class_validator_1.ValidateNested()
], Company.prototype, "properties", void 0);
exports.Company = Company;
(function (Company) {
    class Properties {
        constructor() {
            this.avatar = new avatar_1.Avatar();
            this.address = new address_1.Address();
            this.primary = new contact_1.Contact();
            this.contracted_performance_pct = 80;
            this.secondary = undefined;
            this.domain = '';
            this.user_uri = '';
            this.api_uri = '';
            this.integrations = {};
            this.response_times = this.getDefaultResponseTimes();
            this.setIntegrationDefaults();
            this.transport_provider_notifications = new notification_1.TransportProviderNotification();
            this.care_provider_notifications = new notification_1.CareProviderNotification();
            this.trip_authorization_notifications = new notification_1.AuthorizationNotification();
        }
        getDefaultResponseTimes() {
            return {
                "default": [{ time_to_trip: 15, response_time: 1 },
                    { time_to_trip: 30, response_time: 2 },
                    { time_to_trip: 60, response_time: 4 },
                    { time_to_trip: 90, response_time: 10 },
                    { time_to_trip: 120, response_time: 30 }]
            };
        }
        setIntegrationDefaults() {
            this.addIntegration(exports.FACILITY_API, exports.TRAUMASOFT, "", "", "");
            this.addIntegration(exports.TRIP_API, exports.TRAUMASOFT, "", "", "");
            this.addIntegration(exports.NOTIFICATION_API, exports.TRAUMASOFT, "", "", "");
        }
        hasDefaultIntegrations() {
            return (exports.TRIP_API in this.integrations &&
                exports.FACILITY_API in this.integrations &&
                exports.NOTIFICATION_API in this.integrations);
        }
        addIntegration(type, software, url, name, apikey) {
            this.integrations[type] = { "software": software, "url": url, "name": name, "key": apikey };
        }
    }
    __decorate([
        class_validator_1.IsInt(),
        class_validator_1.Min(0),
        class_validator_1.Max(100)
    ], Properties.prototype, "contracted_performance_pct", void 0);
    __decorate([
        class_validator_1.ValidateNested()
    ], Properties.prototype, "address", void 0);
    __decorate([
        class_validator_1.ValidateNested()
    ], Properties.prototype, "primary", void 0);
    __decorate([
        class_validator_1.ValidateNested()
    ], Properties.prototype, "secondary", void 0);
    Company.Properties = Properties;
})(Company = exports.Company || (exports.Company = {}));
exports.companyservice = new serviceapi_1.ServiceAPI("company");
//# sourceMappingURL=company.js.map