"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.contractservice = exports.Contract = exports.CONTRACT_STATUS = void 0;
const class_validator_1 = require("class-validator");
const serviceapi_1 = require("../serviceapi");
const region_1 = require("./nested/region");
const service_level_1 = require("./nested/service_level");
const job_detail_1 = require("./nested/job_detail");
const datetime_1 = require("./nested/datetime");
exports.CONTRACT_STATUS = {
    DRAFT: "DRAFT",
    PENDING: "PENDING",
    ACTIVE: "ACTIVE"
};
class Contract {
    constructor() {
        // Important !! so server knows what type this is
        this.entity_type = 'contract';
        this.contract_id = -1;
        this.contract_offered_by = -1;
        this.contract_market_id = -1;
        this.contract_offered_to = -1;
        this.contract_care_provider = -1;
        this.contract_transporter = -1;
        this.contract_parent_id = null;
        this.contract_name = '';
        this.contract_type = 'standard';
        this.contract_status = exports.CONTRACT_STATUS.ACTIVE;
        this.created = undefined;
        this.deleted = undefined;
        this.modified = undefined;
        this.setVendorIsCareProvider(false);
        this.properties = new Contract.Properties();
    }
    from(source) {
        var _a;
        this.properties.regions = (_a = this.properties.regions) === null || _a === void 0 ? void 0 : _a.map((region) => {
            return new region_1.Region(region.name, region.area);
        });
        if (this.properties.details) {
            this.properties.details.from();
        }
        if (source.contract_by_id) {
            this.contract_offered_by = source.contract_by_id;
        }
        if (source.external_contract_offered_to) {
            this.contract_offered_to = source.external_contract_offered_to;
        }
    }
    upgrade() {
        if (!this.properties.regions) {
            this.properties.regions = [];
        }
        if (!this.properties.details) {
            this.properties.details = new job_detail_1.JobDetail();
        }
        if (!this.properties.service_level) {
            this.properties.service_level = new service_level_1.ServiceLevel();
        }
    }
    get id() {
        return this.contract_id;
    }
    set id(value) {
        this.contract_id = value;
    }
    get name() {
        return this.contract_name;
    }
    set name(value) {
        this.contract_name = value;
    }
    get companyId() {
        return this.contract_offered_by || -1;
    }
    set companyId(value) {
        this.contract_offered_by = value;
    }
    get marketId() {
        return this.contract_market_id || -1;
    }
    set marketId(value) {
        this.contract_market_id = value;
    }
    get type() {
        return this.contract_type;
    }
    set type(value) {
        this.contract_type = value;
    }
    setVendorIsCareProvider(value) {
        if (value) {
            this.contract_transporter = this.contract_offered_by;
            this.contract_care_provider = this.contract_offered_to;
        }
        else {
            this.contract_transporter = this.contract_offered_to;
            this.contract_care_provider = this.contract_offered_by;
        }
    }
    vendorIsCareProvider() {
        return (this.contract_care_provider == this.contract_offered_to && this.contract_offered_to != -1);
    }
}
__decorate([
    class_validator_1.MaxLength(20)
], Contract.prototype, "contract_status", void 0);
__decorate([
    class_validator_1.ValidateNested()
], Contract.prototype, "properties", void 0);
exports.Contract = Contract;
(function (Contract) {
    class Properties {
        constructor() {
            this.regions = [];
            this.start_dt = new datetime_1.DateTime();
            this.end_dt = new datetime_1.DateTime();
            this.details = new job_detail_1.JobDetail();
            this.service_level = new service_level_1.ServiceLevel();
        }
    }
    Contract.Properties = Properties;
})(Contract = exports.Contract || (exports.Contract = {}));
exports.contractservice = new serviceapi_1.ServiceAPI("contract");
//# sourceMappingURL=contract.js.map