"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.internal_userservice = exports.InternalUser = void 0;
const class_validator_1 = require("class-validator");
const serviceapi_1 = require("../serviceapi");
const contact_1 = require("./nested/contact");
const avatar_1 = require("./nested/avatar");
class InternalUser {
    constructor() {
        // Important !! so server knows what type this is
        this.entity_type = 'internal_user';
        this.internal_user_provider_id = -1;
        this.internal_user_id = -1;
        this.internal_user_name = '';
        this.internal_user_type = '';
        this.internal_user_status = 'ACTIVE';
        this.auth_token = "";
        this.created = undefined;
        this.deleted = undefined;
        this.modified = undefined;
        this.properties = new InternalUser.Properties();
    }
    upgrade() {
        if (!this.properties.avatar) {
            this.properties.avatar = new avatar_1.Avatar();
            this.setAvatar();
        }
    }
    from(source) {
        if (!source.properties.contact) {
            this.firstName = source.properties.first || '';
            this.lastName = source.properties.last || '';
            this.properties.contact.email = source.properties.email || '';
            this.properties.contact.mobile = source.properties.mobile || '';
            delete this.properties['first'];
            delete this.properties['last'];
            delete this.properties['email'];
            delete this.properties['mobile'];
        }
    }
    get id() {
        return this.internal_user_id;
    }
    set id(value) {
        this.internal_user_id = value;
    }
    get providerId() {
        return this.internal_user_provider_id;
    }
    set providerId(value) {
        this.internal_user_provider_id = value;
    }
    get name() {
        return this.internal_user_name;
    }
    set name(value) {
        this.internal_user_name = value;
    }
    get type() {
        return this.internal_user_type;
    }
    set type(value) {
        this.internal_user_type = value;
    }
    get status() {
        return this.internal_user_status;
    }
    set status(value) {
        this.internal_user_status = value;
    }
    get password() {
        return this.auth_token;
    }
    set password(value) {
        this.auth_token = value;
    }
    get generatePW() {
        return this.properties.generate_password || "";
    }
    set generatePW(value) {
        this.properties.generate_password = value;
    }
    get firstName() {
        return this.properties.contact.firstname || '';
    }
    get lastName() {
        return this.properties.contact.lastname || '';
    }
    get middleName() {
        return this.properties.contact.middlename || '';
    }
    set firstName(value) {
        this.properties.contact.firstname = value;
        this.setAvatar();
    }
    set lastName(value) {
        this.properties.contact.lastname = value;
        this.setAvatar();
    }
    set middleName(value) {
        this.properties.contact.middlename = value;
        this.setAvatar();
    }
    setAvatar() {
        let f = this.firstName.substring(0, 1).toUpperCase();
        let m = this.middleName.substring(0, 1).toUpperCase();
        let l = this.lastName.substring(0, 1).toUpperCase();
        this.properties.avatar.label = f + m + l;
    }
    getToken() {
        return Math.random().toString(36).slice(2) + Math.random().toString(36).slice(2);
    }
    initUserAuthorization() {
        if (this.generatePW == "true") {
            this.status = "PENDING";
            this.password = this.getToken();
        }
    }
    hasActivationToken() {
        return (this.properties.activation_token != null);
    }
    getActivationURI() {
        if (this.generatePW == "true" && this.hasActivationToken()) {
            let token = this.properties.activation_token.token;
            return "/account/activation?provider={provider}&token={token}&name={name}"
                .replace("{provider}", this.providerId.toString())
                .replace("{token}", token)
                .replace("{name}", this.name);
        }
        return "/";
    }
    get tokenExpiration() {
        return this.properties.activation_token.expiration;
    }
}
__decorate([
    class_validator_1.MaxLength(30)
], InternalUser.prototype, "internal_user_name", void 0);
__decorate([
    class_validator_1.ValidateNested()
], InternalUser.prototype, "properties", void 0);
exports.InternalUser = InternalUser;
(function (InternalUser) {
    class Properties {
        constructor() {
            this.avatar = new avatar_1.Avatar();
            this.contact = new contact_1.Contact();
            this.directories = [];
            this.generate_password = "true";
            this.activation_token = null;
        }
    }
    InternalUser.Properties = Properties;
})(InternalUser = exports.InternalUser || (exports.InternalUser = {}));
exports.internal_userservice = new serviceapi_1.ServiceAPI("internal_user");
//# sourceMappingURL=internal_user.js.map