"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.itineraryservice = exports.Itinerary = exports.ITINERARY_STATUS = void 0;
const class_validator_1 = require("class-validator");
const serviceapi_1 = require("../serviceapi");
const destination_1 = require("./nested/destination");
const job_detail_1 = require("./nested/job_detail");
const helper_1 = require("../helper");
const datetime_1 = require("./nested/datetime");
const question_1 = require("./question");
const comment_1 = require("./nested/comment");
const recurrence_1 = require("./nested/recurrence");
const dayjs_1 = __importDefault(require("dayjs"));
const trip_1 = require("./trip");
const appointment_types_1 = require("../const/appointment_types");
const itinerary_type_1 = require("../const/itinerary_type");
exports.ITINERARY_STATUS = {
    DRAFT: "DRAFT",
    ACTIVE: "ACTIVE",
    COMPLETED: "COMPLETED"
};
class Itinerary {
    constructor() {
        // Important !! so server knows what type this is
        this.entity_type = 'itinerary';
        this.itinerary_id = -1;
        this.itinerary_company_id = -1;
        this.itinerary_market_id = -1;
        this.itinerary_patient_id = -1;
        this.itinerary_type = itinerary_type_1.ITINERARY_TYPE.SINGLE;
        this.itinerary_name = this.uuidv4();
        this.itinerary_status = exports.ITINERARY_STATUS.ACTIVE;
        this.created = undefined;
        this.deleted = undefined;
        this.modified = undefined;
        this.properties = new Itinerary.Properties();
    }
    upgrade() {
    }
    from(source) {
        var _a, _b;
        if (this.properties.details) {
            this.properties.details.from();
        }
        this.properties.questions = (_a = this.properties.questions) === null || _a === void 0 ? void 0 : _a.map((item) => {
            return helper_1.instance.ObjectClone(new question_1.Question(), item);
        });
        this.properties.comments = (_b = this.properties.comments) === null || _b === void 0 ? void 0 : _b.map((item) => {
            return helper_1.instance.ObjectClone(new comment_1.Comment(), item);
        });
    }
    get id() {
        return this.itinerary_id;
    }
    set id(value) {
        this.itinerary_id = value;
    }
    get reference() {
        return this.itinerary_name;
    }
    set reference(value) {
        this.itinerary_name = value;
    }
    get companyId() {
        return this.itinerary_company_id;
    }
    set companyId(value) {
        this.itinerary_company_id = value;
    }
    get marketId() {
        return this.itinerary_market_id;
    }
    set marketId(value) {
        this.itinerary_market_id = value;
    }
    get patientId() {
        return this.itinerary_patient_id;
    }
    set patientId(value) {
        this.itinerary_patient_id = value;
    }
    set type(value) {
        this.itinerary_type = value;
    }
    get type() {
        return this.itinerary_type;
    }
    set returnPickUpType(value) {
        this.properties.return_pick_up_type = value;
    }
    get returnPickUpType() {
        return this.properties.return_pick_up_type;
    }
    get isOneWay() {
        return this.type == itinerary_type_1.ITINERARY_TYPE.SINGLE;
    }
    get isRoundTrip() {
        return this.type == itinerary_type_1.ITINERARY_TYPE.ROUND;
    }
    get isMultiLeg() {
        return this.type == itinerary_type_1.ITINERARY_TYPE.MULTI;
    }
    get usePatientCertification() {
        return this.properties.use_patient_certification;
    }
    set usePatientCertification(value) {
        this.properties.use_patient_certification = value;
        if (!value) {
            //
            //clear the job details 
            //
            this.properties.details.clear();
            this.properties.questions.forEach(q => {
                q.checked = false;
            });
            this.properties.questions = [];
        }
    }
    uuidv4() {
        let guid = 'xxx-xxxx'.replace(/[xy]/g, function (c) {
            var r = Math.random() * 16 | 0, v = c == 'x' ? r : (r & 0x3 | 0x8);
            return v.toString(16);
        });
        return guid.toUpperCase() + "-" + dayjs_1.default().format("HHmm");
    }
    setLegs() {
        this.properties.trips = [];
        this.properties.trips.push(this.generateALeg());
        if (this.type == itinerary_type_1.ITINERARY_TYPE.ROUND) {
            this.properties.trips.push(this.generateBLeg());
        }
    }
    generateALeg() {
        return this.setALeg(new trip_1.Trip());
    }
    generateBLeg() {
        return this.setBLeg(new trip_1.Trip());
    }
    setALeg(leg) {
        leg.trip_itinerary_id = this.itinerary_id;
        leg.itinerary_market_id = this.marketId;
        leg.properties.route_summary = this.properties.route_summary;
        leg.properties.type_lov_id = this.properties.details.types.length > 0 ? this.properties.details.types[0].lov_alias_lov_id : -1;
        leg.properties.priority_lov_id = this.properties.details.priorities.length > 0 ? this.properties.details.priorities[0].lov_alias_lov_id : -1;
        leg.properties.variables = this.properties.details.nonDispatchVariables;
        leg.properties.details = helper_1.instance.ObjectClone(leg.properties.details, this.properties.details);
        leg.properties.pick_up = helper_1.instance.ObjectClone(leg.properties.pick_up, this.properties.pick_up);
        leg.properties.drop_off = this.properties.drop_off;
        return leg;
    }
    setBLeg(leg) {
        leg.trip_itinerary_id = this.itinerary_id;
        leg.itinerary_market_id = this.marketId;
        leg.properties.route_summary = this.properties.route_summary;
        leg.properties.type_lov_id = this.properties.details.types.length > 0 ? this.properties.details.types[0].lov_alias_lov_id : -1;
        leg.properties.priority_lov_id = this.properties.details.priorities.length > 0 ? this.properties.details.priorities[0].lov_alias_lov_id : -1;
        leg.properties.variables = this.properties.details.nonDispatchVariables;
        leg.properties.details = helper_1.instance.ObjectClone(leg.properties.details, this.properties.details);
        // SWAP P/U and D/O addresses
        leg.properties.pick_up = new destination_1.Destination();
        leg.properties.pick_up.address = helper_1.instance.ObjectClone(leg.properties.pick_up.address, this.properties.drop_off.address);
        leg.properties.drop_off = new destination_1.Destination();
        leg.properties.drop_off.address = helper_1.instance.ObjectClone(leg.properties.drop_off.address, this.properties.pick_up.address);
        // Pick up DT of B Leg is the return DT entered
        leg.properties.return_pick_up_type = this.properties.return_pick_up_type;
        leg.properties.pick_up.dt = helper_1.instance.ObjectClone(leg.properties.pick_up.dt, this.properties.return_pick_up_dt);
        leg.properties.drop_off.dt = new datetime_1.DateTime();
        return leg;
    }
    get aLeg() {
        return this.generateALeg();
    }
}
__decorate([
    class_validator_1.MaxLength(20)
], Itinerary.prototype, "itinerary_status", void 0);
__decorate([
    class_validator_1.ValidateNested()
], Itinerary.prototype, "properties", void 0);
exports.Itinerary = Itinerary;
(function (Itinerary) {
    class Properties {
        constructor() {
            this.trips = [];
            this.originator_review = false;
            this.transporter_review = false;
            this.return_pick_up_type = appointment_types_1.APPOINTMENT_PICKUP_TYPE.WILLCALL;
            this.return_pick_up_dt = new datetime_1.DateTime();
            this.details = new job_detail_1.JobDetail();
            this.use_patient_certification = false;
            this.pick_up = new destination_1.Destination();
            this.drop_off = new destination_1.Destination();
            this.route_summary = {};
            this.questions = [];
            this.comments = [];
            this.recurrence = new recurrence_1.Recurrence();
        }
    }
    Itinerary.Properties = Properties;
})(Itinerary = exports.Itinerary || (exports.Itinerary = {}));
exports.itineraryservice = new serviceapi_1.ServiceAPI("itinerary");
//# sourceMappingURL=itinerary.js.map