"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.facilitytypeservice = exports.companytypeservice = exports.calltypeservice = exports.callpriorityservice = exports.losservice = exports.addressstateservice = exports.CallType = exports.CompanyType = exports.Properties = exports.Lov = exports.PARAMETER_UNITS = exports.PARAMETER_TYPES = exports.PARAMETER = exports.FACILITY_TYPE = exports.LEVEL_OF_SERVICE = exports.CALL_PRIORITY = exports.CALL_TYPE = exports.COMPANY_TYPE = exports.ADDRESS_STATE = void 0;
const serviceapi_1 = require("../../serviceapi");
exports.ADDRESS_STATE = "address_state";
exports.COMPANY_TYPE = "company_type";
exports.CALL_TYPE = "call_type";
exports.CALL_PRIORITY = "call_priority";
exports.LEVEL_OF_SERVICE = "level_of_service";
exports.FACILITY_TYPE = "facility_type";
exports.PARAMETER = {
    TYPES: { TIMEOFDAY: "1", DAYOFWEEK: "2", QTY: "3" },
    UNITS: { MINUTE: "0", WEIGHT: "1", VOLUME: "2", COUNT: "3" }
};
exports.PARAMETER_TYPES = [{ id: exports.PARAMETER.TYPES.TIMEOFDAY, label: 'Time of day' },
    { id: exports.PARAMETER.TYPES.DAYOFWEEK, label: 'Day of week' },
    { id: exports.PARAMETER.TYPES.QTY, label: 'Quantity' }];
exports.PARAMETER_UNITS = [{ id: exports.PARAMETER.UNITS.MINUTE, label: 'Minutes' },
    { id: exports.PARAMETER.UNITS.WEIGHT, label: 'Weight' },
    { id: exports.PARAMETER.UNITS.VOLUME, label: 'Volume' },
    { id: exports.PARAMETER.UNITS.COUNT, label: 'Count' }];
let typeMap = {};
class Lov {
    constructor(lov_type) {
        // Important !! so server knows what type this is
        this.entity_type = 'lov';
        this.lov_id = -1;
        this.lov_name = '';
        this.lov_type = lov_type;
        this.created = undefined;
        this.deleted = undefined;
        this.modified = undefined;
        this.properties = new (typeMap[lov_type] || Properties)();
        if (lov_type == exports.CALL_PRIORITY) {
            this.properties.parameter_type = exports.PARAMETER.TYPES.QTY;
            this.properties.parameter_unit = exports.PARAMETER.UNITS.MINUTE;
        }
    }
    upgrade() {
    }
    get id() {
        return this.lov_id;
    }
    set id(value) {
        this.lov_id = value;
    }
    get code() {
        return this.lov_name;
    }
    set code(value) {
        this.lov_name = value;
    }
    get displayName() {
        return this.properties.display_name || '';
    }
    set displayName(value) {
        this.properties.display_name = value;
    }
    get type() {
        return this.lov_type;
    }
    set type(value) {
        this.lov_type = value;
    }
    get isQtyParameter() {
        return this.properties.parameter_type == exports.PARAMETER.TYPES.QTY;
    }
    get parameterTypes() {
        return exports.PARAMETER_TYPES;
    }
    get parameterUnits() {
        return exports.PARAMETER_UNITS;
    }
    get parameterTypeDisplay() {
        if (this.properties.parameter_type != '') {
            for (let i = 0; i < exports.PARAMETER_TYPES.length; i++) {
                let e = exports.PARAMETER_TYPES[i];
                if (e.id == this.properties.parameter_type) {
                    return e.label;
                    break;
                }
            }
        }
        return '';
    }
    get parameterUnitDisplay() {
        if (this.properties.parameter_unit != '') {
            for (let i = 0; i < exports.PARAMETER_UNITS.length; i++) {
                let e = exports.PARAMETER_UNITS[i];
                if (e.id == this.properties.parameter_unit) {
                    return e.label;
                    break;
                }
            }
        }
        return '';
    }
}
exports.Lov = Lov;
class Properties {
    constructor() {
        this.display_name = '';
        this.parameter_type = '';
        this.parameter_unit = '';
    }
    init() {
        this.display_name = '';
        this.parameter_type = '';
        this.parameter_unit = '';
    }
    static instance(entity_type) {
        return new Lov(entity_type);
    }
}
exports.Properties = Properties;
class CompanyType extends Properties {
    constructor() {
        super();
        this.transport_provider = "false";
        this.care_provider = "false";
        this.authorize_bookings = "false";
    }
    static instance() {
        let o = new Lov(exports.COMPANY_TYPE);
        return o;
    }
}
exports.CompanyType = CompanyType;
class CallType extends Properties {
    static instance() {
        return new Lov(exports.CALL_TYPE);
    }
    constructor() {
        super();
    }
}
exports.CallType = CallType;
typeMap[exports.COMPANY_TYPE] = CompanyType;
typeMap[exports.CALL_TYPE] = CallType;
exports.addressstateservice = new serviceapi_1.ServiceAPI(exports.ADDRESS_STATE);
exports.losservice = new serviceapi_1.ServiceAPI(exports.LEVEL_OF_SERVICE);
exports.callpriorityservice = new serviceapi_1.ServiceAPI(exports.CALL_PRIORITY);
exports.calltypeservice = new serviceapi_1.ServiceAPI(exports.CALL_TYPE);
exports.companytypeservice = new serviceapi_1.ServiceAPI(exports.COMPANY_TYPE);
exports.facilitytypeservice = new serviceapi_1.ServiceAPI(exports.FACILITY_TYPE);
//# sourceMappingURL=lov.js.map