"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Address = void 0;
class Address {
    constructor() {
        this.line1 = undefined;
        this.line2 = undefined;
        this.line3 = undefined;
        this.city = undefined;
        this.state = undefined;
        this.postcode = undefined;
        this.country = undefined;
        this.country_code = undefined;
        this.location_id = undefined;
        this.county = undefined;
        this.map = undefined;
        this.line3 = '';
        this.line1 = '';
        this.line2 = '';
        this.city = '';
        this.state = '';
        this.postcode = '';
        this.country = '';
        this.location_id = '';
        this.county = '';
        this.country_code = '';
        this.map = {
            timezone: "",
            position: { latitude: "", longitude: "" },
            mapView: { latitude: "", longitude: "" },
        };
    }
    get isValid() {
        let x = (typeof this.city != 'undefined' &&
            typeof this.state != 'undefined' &&
            typeof this.postcode != 'undefined');
        let y = (this.streetAdressLine != "" &&
            this.city != "" &&
            this.state != "" &&
            this.postcode != "");
        return (x && y);
    }
    get isValidRegion() {
        let x = (typeof this.city != 'undefined' ||
            typeof this.state != 'undefined' ||
            typeof this.county != 'undefined' ||
            typeof this.postcode != 'undefined');
        let y = (this.city != "" ||
            this.state != "" ||
            this.county != "" ||
            this.postcode != "");
        return (x && y);
    }
    get summary() {
        return this.isValid ? this.label : "";
    }
    get streetAdressLine() {
        let streetAddress = "";
        if (this.validValue(this.line1)) {
            streetAddress = this.line1;
        }
        if (this.validValue(this.line2)) {
            streetAddress = streetAddress + " " + this.line2;
        }
        if (this.validValue(this.line3)) {
            streetAddress = streetAddress + " " + this.line3;
        }
        return streetAddress.trim();
    }
    get cityAddressLine() {
        let res = [];
        if (this.validValue(this.city)) {
            res.push(this.city);
        }
        else if (this.validValue(this.county)) {
            res.push(this.county);
        }
        if (this.validValue(this.state)) {
            res.push(this.state);
        }
        let a = res.join(', ');
        if (this.validValue(this.postcode)) {
            a = a + " " + this.postcode;
        }
        //if (this.validValue(this.country)) {
        //  a = a + " " + this.country;
        //}
        return a;
    }
    get label() {
        let res = [];
        if (this.validValue(this.streetAdressLine)) {
            res.push(this.streetAdressLine);
        }
        if (this.validValue(this.cityAddressLine)) {
            res.push(this.cityAddressLine);
        }
        return res.join(', ');
    }
    validValue(value) {
        return (value && value.length > 0);
    }
    initFromAddressRec(rec) {
        this.line1 = rec.address.houseNumber ? rec.address.houseNumber : "";
        this.line2 = rec.address.street ? rec.address.street : "";
        this.city = rec.address.city ? rec.address.city : "";
        this.state = rec.address.state ? rec.address.state : "";
        this.postcode = rec.address.postalCode ? rec.address.postalCode : "";
        this.country = rec.address.country ? rec.address.country : "";
        this.location_id = rec.locationId;
        this.county = rec.address.county ? rec.address.county : "";
        this.country_code = rec.countryCode;
    }
}
exports.Address = Address;
//# sourceMappingURL=address.js.map