"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DateTime = exports.TimeZone = void 0;
const api_1 = require("../../api");
class TimeZone {
    constructor() {
        this.id = '';
        this.nameDst = '';
        this.name = '';
        this.offset = null;
    }
}
exports.TimeZone = TimeZone;
class DateTime {
    constructor() {
        this.day = '';
        this.epoch = -1;
        this.time_of_day = '';
        //default tz to session tz
        this.tz = new TimeZone();
        this.tz.id = api_1.Api.instance().tz;
    }
    from(source) {
        if (source.dt) {
            this.day = source.dt;
        }
    }
    set datetime(value) {
        if (value != '' && value != "T") {
            let x = value.split("T");
            this.date = x[0];
            this.time = x[1];
        }
        else {
            this.date = "";
            this.time = "";
        }
    }
    setTimeZoneFromApiRec(apiRec) {
        this.tz.id = apiRec.id;
        this.tz.nameDst = apiRec.nameDstShort;
        this.tz.name = apiRec.nameShort;
        this.tz.offset = apiRec.offset;
    }
    get timezone() {
        return this.tz.id;
    }
    set timezone(value) {
        this.tz.id = value;
    }
    get datetime() {
        if (this.day != "" && this.time_of_day != "") {
            return this.day + "T" + this.time_of_day;
        }
        else if (this.day) {
            return this.day + "T00:00";
        }
        else {
            return "";
        }
    }
    get time() {
        return this.time_of_day;
    }
    set time(value) {
        this.time_of_day = value;
        this.setEpoch();
    }
    get date() {
        return this.day;
    }
    set date(value) {
        this.day = value;
        this.setEpoch();
    }
    setEpoch() {
        //
        // Keep the entered date time but make the TZ be the server TZ
        // eg. 2000-01-01 00:00 local becomes 2000-01-01-00:00 EST
        // where EST is the server's TZ
        let api = api_1.Api.instance();
        let dt = api.asServerDT(this.datetime);
        this.epoch = dt.isValid() ? dt.unix() : -1;
    }
}
exports.DateTime = DateTime;
//# sourceMappingURL=datetime.js.map