"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JobDetail = exports.Pricing = void 0;
const helper_1 = require("../../helper");
const lov_1 = require("../lovs/lov");
const lov_alias_1 = require("../lovs/lov_alias");
const lov_2 = require("../lovs/lov");
var DistanceUnit;
(function (DistanceUnit) {
    DistanceUnit[DistanceUnit["mile"] = 1] = "mile";
    DistanceUnit[DistanceUnit["kilometer"] = 2] = "kilometer";
})(DistanceUnit || (DistanceUnit = {}));
class Pricing {
    constructor() {
        this.base_rate = 0;
        this.per_unit_rate = 0;
        this.unit = DistanceUnit.mile;
        this.free_units = 10;
        this.rates = [];
    }
    addRate(id, type, code, name, amount, ptype, punit, poperator, pamount, pamount2, displaytype, lov_id) {
        let rate = {
            id: id, type: type, code: code, name: name, amount: amount,
            parameter_type: ptype,
            parameter_unit: punit,
            parameter_operator: poperator,
            parameter_amount: pamount,
            parameter_amount_2: pamount2,
            input_value: '',
            display_type: displaytype,
            lov_id: lov_id
        };
        this.rates.push(rate);
        return rate;
    }
    get ratesWithInputValues() {
        return this.rates.filter(item => item.parameter_type == lov_1.PARAMETER.TYPES.QTY && item.parameter_unit != lov_1.PARAMETER.UNITS.MINUTE);
    }
}
exports.Pricing = Pricing;
class JobDetail {
    constructor() {
        this.types = [];
        this.variable = [];
        this.priorities = [];
        this.pricing = new Pricing();
        this.priorities_lov_id = [];
        this.variables_lov_id = [];
        this.types_lov_id = [];
    }
    get typesSummary() {
        let x = [];
        this.types.forEach(item => {
            x.push(item.code);
        });
        return x.join(", ");
    }
    get prioritiesSummary() {
        let x = [];
        this.priorities.forEach(item => {
            x.push(item.code);
        });
        return x.join(", ");
    }
    get nonDispatchVariables() {
        return this.pricing.rates.filter(item => item.parameter_type != lov_1.PARAMETER.TYPES.DAYOFWEEK &&
            item.parameter_type != lov_1.PARAMETER.TYPES.TIMEOFDAY &&
            item.lov_type == lov_2.LEVEL_OF_SERVICE);
    }
    get timeBasedParams() {
        return this.includeTimeBasedParams(this.variable);
    }
    get noTimeBasedParams() {
        return this.excludeTimeBasedParams(this.variable);
    }
    paramIsTimeBased(item) {
        return (item.lov_properties.parameter_type == lov_1.PARAMETER.TYPES.DAYOFWEEK ||
            item.lov_properties.parameter_type == lov_1.PARAMETER.TYPES.TIMEOFDAY);
    }
    includeTimeBasedParams(items) {
        return items.filter(item => this.paramIsTimeBased(item));
    }
    excludeTimeBasedParams(items) {
        return items.filter(item => !this.paramIsTimeBased(item));
    }
    from() {
        this.types = this.types.map(e => {
            let x = lov_alias_1.Properties.instance(lov_alias_1.CALL_TYPE_ALIAS);
            helper_1.instance.ObjectClone(x, e);
            return x;
        });
        this.priorities = this.priorities.map(e => {
            let x = lov_alias_1.Properties.instance(lov_alias_1.CALL_PRIORITY_ALIAS);
            helper_1.instance.ObjectClone(x, e);
            return x;
        });
        this.variable = this.variable.map(e => {
            let x = lov_alias_1.Properties.instance(lov_alias_1.LEVEL_OF_SERVICE_ALIAS);
            helper_1.instance.ObjectClone(x, e);
            return x;
        });
    }
    addType(item, list, type) {
        if (list.indexOf(item) == -1) {
            list.push(item);
        }
        let x = helper_1.instance.getArrayItemByID(this.pricing.rates, item.id);
        if (!x) {
            let operator = '';
            if (item.properties.parameter_type == lov_1.PARAMETER.TYPES.TIMEOFDAY || item.properties.parameter_type == lov_1.PARAMETER.TYPES.QTY) {
                operator = "BETWEEN";
            }
            if (item.properties.parameter_type == lov_1.PARAMETER.TYPES.DAYOFWEEK) {
                operator = "IN";
            }
            let o = this.pricing.addRate(item.id, item.lov_type, item.code, item.displayName, item.properties.value ? item.properties.value : 0, item.properties.parameter_type, item.properties.parameter_unit, operator, '', '', type, item.lov_alias_lov_id);
            if (item.properties.parameter_type == lov_1.PARAMETER.TYPES.QTY) {
                o.parameter_unit_display = item.parameterUnitDisplay;
            }
            this.pricing.rates.sort((a, b) => (a.type > b.type) ? 1 : ((b.type > a.type) ? -1 : 0));
        }
    }
    delType(item, list) {
        let ndx = list.indexOf(item);
        list.splice(ndx, 1);
        //
        let o = helper_1.instance.getArrayItemByID(this.pricing.rates, item.id);
        let n = this.pricing.rates.indexOf(o);
        this.pricing.rates.splice(n, 1);
    }
    addCallType(item) {
        if (item) {
            if (this.types_lov_id.indexOf(item.lov_alias_lov_id) < 0) {
                this.types_lov_id.push(item.lov_alias_lov_id);
            }
            this.addType(item, this.types, "Call Type");
        }
    }
    addPriority(item) {
        if (item) {
            if (this.priorities_lov_id.indexOf(item.lov_alias_lov_id) < 0) {
                this.priorities_lov_id.push(item.lov_alias_lov_id);
            }
            this.addType(item, this.priorities, "Priority");
        }
    }
    addVariable(item) {
        if (item) {
            if (this.variables_lov_id.indexOf(item.lov_alias_lov_id) < 0) {
                this.variables_lov_id.push(item.lov_alias_lov_id);
            }
            this.addType(item, this.variable, "Variable");
        }
    }
    delCallType(item) {
        let ndx = this.types_lov_id.indexOf(item.lov_alias_lov_id);
        this.types_lov_id.splice(ndx, 1);
        this.delType(item, this.types);
    }
    delPriority(item) {
        let ndx = this.priorities_lov_id.indexOf(item.lov_alias_lov_id);
        this.priorities_lov_id.splice(ndx, 1);
        this.delType(item, this.priorities);
    }
    delVariable(item) {
        let ndx = this.variables_lov_id.indexOf(item.lov_alias_lov_id);
        this.variables_lov_id.splice(ndx, 1);
        this.delType(item, this.variable);
    }
    clearCallTypes() {
        this.types.forEach(item => {
            this.delCallType(item);
        });
    }
    clearPriorities() {
        this.priorities.forEach(item => {
            this.delPriority(item);
        });
    }
    clearVariables() {
        this.variable.forEach(item => {
            this.delVariable(item);
        });
    }
    clear() {
        this.clearCallTypes();
        this.clearPriorities();
        this.clearVariables();
    }
}
exports.JobDetail = JobDetail;
//# sourceMappingURL=job_detail.js.map