"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.patientservice = exports.Patient = void 0;
const class_validator_1 = require("class-validator");
const address_1 = require("./nested/address");
const contact_1 = require("./nested/contact");
const person_traits_1 = require("./nested/person_traits");
const payor_1 = require("./nested/payor");
const serviceapi_1 = require("../serviceapi");
const helper_1 = require("../helper");
const api_1 = require("../api");
class Patient {
    constructor() {
        // Important !! so server knows what type this is
        this.entity_type = 'patient';
        this.patient_id = -1;
        this.patient_company_id = -1;
        this.patient_name = '';
        this.patient_type = '';
        this.patient_status = 'ACTIVE';
        this.created = undefined;
        this.deleted = undefined;
        this.modified = undefined;
        this.properties = new Patient.Properties();
    }
    upgrade() {
    }
    from(source) {
        var _a;
        this.properties.payors = (_a = this.properties.payors) === null || _a === void 0 ? void 0 : _a.map((e) => {
            return helper_1.instance.ObjectClone(new payor_1.Payor(), e);
        });
    }
    get id() {
        return this.patient_id;
    }
    set id(value) {
        this.patient_id = value;
    }
    get reference() {
        return this.patient_name;
    }
    set reference(value) {
        this.patient_name = value;
    }
    get type() {
        return this.patient_type;
    }
    set type(value) {
        this.patient_type = value;
    }
    get company_id() {
        return this.patient_company_id || -1;
    }
    set company_id(value) {
        this.patient_company_id = value;
    }
    get coverageLOV() {
        return payor_1.Payor.coverageList();
    }
    get genderLOV() {
        return person_traits_1.PersonTraits.genderList();
    }
    get displayName() {
        return this.properties.contact.displayName;
    }
    addPayor(payor) {
        var _a;
        (_a = this.properties.payors) === null || _a === void 0 ? void 0 : _a.push(payor ? payor : new payor_1.Payor());
    }
    deletePayor(item) {
        let x = this.properties.payors.indexOf(item);
        if (x != undefined && x != -1) {
            this.properties.payors.splice(x, 1);
        }
    }
}
__decorate([
    class_validator_1.ValidateNested()
], Patient.prototype, "properties", void 0);
exports.Patient = Patient;
(function (Patient) {
    class Properties {
        constructor() {
            this.in_facility = false;
            this.facility_id = null;
            this.facility_patient_location = '';
            this.access_expiration_date = '';
            this.medicare_number = '';
            this.medicaid_number = '';
            this.payors = [];
            this.contact = new contact_1.Contact();
            this.traits = new person_traits_1.PersonTraits();
            this.residence = new address_1.Address();
            let api = api_1.Api.instance();
            this.residence.country = api.countryCode;
        }
        get medicareSummary() {
            let res = [];
            if (this.medicare_number) {
                res.push("Medicare: " + this.medicare_number);
            }
            if (this.validValue(this.medicaid_number)) {
                res.push("Medicaid: " + this.medicaid_number);
            }
            return res.join(', ');
        }
        validValue(value) {
            return (value && value.length > 0);
        }
    }
    __decorate([
        class_validator_1.ValidateNested()
    ], Properties.prototype, "residence", void 0);
    __decorate([
        class_validator_1.ValidateNested()
    ], Properties.prototype, "contact", void 0);
    __decorate([
        class_validator_1.ValidateNested()
    ], Properties.prototype, "traits", void 0);
    Patient.Properties = Properties;
})(Patient = exports.Patient || (exports.Patient = {}));
exports.patientservice = new serviceapi_1.ServiceAPI("patient");
//# sourceMappingURL=patient.js.map