"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.tripservice = exports.Trip = void 0;
const class_validator_1 = require("class-validator");
const serviceapi_1 = require("../serviceapi");
const destination_1 = require("./nested/destination");
const completion_1 = require("./nested/completion");
const helper_1 = require("../helper");
const job_detail_1 = require("./nested/job_detail");
const appointment_types_1 = require("../const/appointment_types");
class Trip {
    constructor() {
        // Important !! so server knows what type this is
        this.entity_type = 'trip';
        this.trip_id = -1;
        this.trip_itinerary_id = null;
        this.trip_transport_id = null;
        this.itinerary_market_id = -1;
        this.trip_type = '';
        this.trip_name = '';
        this.trip_status = 'ACTIVE';
        this.created = undefined;
        this.deleted = undefined;
        this.modified = undefined;
        this.properties = new Trip.Properties();
    }
    upgrade() {
        if (!this.properties.completion) {
            this.properties.completion = new completion_1.Completion();
        }
    }
    from(source) {
        let helper = helper_1.Helper.instance();
        if (!(this.properties.drop_off instanceof destination_1.Destination)) {
            this.properties.drop_off = helper.ObjectClone(new destination_1.Destination(), this.properties.drop_off);
            this.properties.drop_off = helper.ObjectClone(new destination_1.Destination(), source.properties.drop_off);
        }
        if (!(this.properties.pick_up instanceof destination_1.Destination)) {
            this.properties.pick_up = helper.ObjectClone(new destination_1.Destination(), this.properties.pick_up);
            this.properties.pick_up = helper.ObjectClone(new destination_1.Destination(), source.properties.pick_up);
        }
        if (source.trip_properties) {
            this.properties = helper.ObjectClone(this.properties, source.trip_properties);
        }
    }
    get id() {
        return this.trip_id;
    }
    set id(value) {
        this.trip_id = value;
    }
    get reference() {
        return this.trip_name;
    }
    set reference(value) {
        this.trip_name = value;
    }
    set type(value) {
        this.trip_type = value;
    }
    get type() {
        return this.trip_type;
    }
    //get companyId(): number {
    //    return this.trip_company_id;
    //}
    //set companyId(value: number) {
    //    this.trip_company_id = value;
    //}
    //get marketId(): number {
    //    return this.trip_market_id;
    //}
    //set marketId(value: number) {
    //    this.trip_market_id = value;
    //}
    //get patientId(): number {
    //    return this.trip_patient_id;
    //}
    //set patientId(value: number) {
    //    this.trip_patient_id = value;
    //}
    get canCalculateVariables() {
        let errors = [];
        if (this.properties.type_lov_id == -1) {
            errors.push({ error: "Call type not set." });
        }
        if (this.itinerary_market_id == -1) {
            errors.push({ error: "Invalid market id." });
        }
        if (!(this.properties.pick_up.isValid)) {
            errors.push({ error: "Pick Up address is invalid" });
        }
        if (!(this.properties.drop_off.isValid)) {
            errors.push({ error: "Drop Off address is invalid" });
        }
        if (this.properties.pick_up.dt.epoch == -1) {
            errors.push({ error: "Pick Up time is invalid." });
        }
        return { response: (errors.length == 0), errors: errors };
    }
    get reasonInvalid() {
        let x = [];
        if (this.properties.type_lov_id == -1) {
            x.push({ error: "invalid call type", value: -1 });
        }
        if (this.itinerary_market_id == -1) {
            x.push({ error: "invalid market", value: -1 });
        }
        if (!this.properties.pick_up.isValid) {
            x.push({ error: "invalid pick up address", value: this.properties.pick_up });
        }
        if (this.properties.pick_up.dt.epoch == -1) {
            x.push({ error: "invalid pick up time", value: this.properties.pick_up.dt.epoch });
        }
        if (!this.properties.drop_off.isValid) {
            x.push({ error: "invalid drop off address", value: this.properties.drop_off });
        }
        return x;
    }
}
__decorate([
    class_validator_1.MaxLength(20)
], Trip.prototype, "trip_status", void 0);
__decorate([
    class_validator_1.ValidateNested()
], Trip.prototype, "properties", void 0);
exports.Trip = Trip;
(function (Trip) {
    class Properties {
        constructor() {
            this.originator_review = false;
            this.transporter_review = false;
            this.batch_originator_review = false;
            this.batch_transporter_review = false;
            this.type_lov_id = -1;
            this.priority_lov_id = -1;
            this.dispatch_variables_lov_id = [];
            this.return_pick_up_type = appointment_types_1.APPOINTMENT_PICKUP_TYPE.WILLCALL;
            this.variables = [];
            this.patient = {};
            this.route_summary = {};
            this.pick_up = new destination_1.Destination();
            this.drop_off = new destination_1.Destination();
            this.completion = new completion_1.Completion();
            this.details = new job_detail_1.JobDetail();
        }
    }
    Trip.Properties = Properties;
})(Trip = exports.Trip || (exports.Trip = {}));
exports.tripservice = new serviceapi_1.ServiceAPI("trip");
//# sourceMappingURL=trip.js.map