"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServiceSubClassAPI = exports.ServiceAPI = void 0;
const class_validator_1 = require("class-validator");
const api_1 = require("./api");
const helper_1 = require("./helper");
const dialogs_1 = require("./dialogs");
let api = api_1.Api.instance();
/**
 * Generic casting info
 * @see https://stackoverflow.com/questions/39392853/is-there-a-type-for-class-in-typescript-and-does-any-include-it
 *
 * @TODO revisit readall and read to see if we can avoid passing in a new Generic from vue
 */
class ServiceAPI {
    constructor(entityType) {
        this._entityType = entityType;
    }
    get entityType() {
        return this._entityType;
    }
    createEntity(type) {
        return new type();
    }
    async readAll(entity, parameters) {
        if (api.isConnected) {
            return await api.operation(this._entityType + ".readall", parameters).then((data) => {
                //api.log("READALL", data);
                //if a search is defined, then readall will return a page
                let rows = data.data ? data.data : data;
                let res = rows.map((r) => {
                    let t = new (Object.getPrototypeOf(entity).constructor)();
                    return helper_1.instance.ObjectClone(t, r);
                });
                return Promise.resolve(res);
            });
        }
        else {
            return [];
        }
    }
    async search(entity, options, parameters) {
        if (api.isConnected) {
            let json = options;
            if (parameters != undefined) {
                json.params = parameters;
            }
            return await api.operation(this._entityType + ".search", json).then((page) => {
                let data = page.data;
                let res = data.map((r) => {
                    let t = new (Object.getPrototypeOf(entity).constructor)();
                    return helper_1.instance.ObjectClone(t, r);
                });
                page.data = res;
                return Promise.resolve(page);
            });
        }
        else {
            return [];
        }
    }
    /**
     * read will populate entity passed in with data from the server and return it.
     * @param entity
     * @param id
     */
    async read(entity, id) {
        let json = "{\"" + this._entityType + "_id\":" + id + "}";
        let e = await api.read(this._entityType + ".read", json);
        return helper_1.instance.ObjectClone(entity, e);
    }
    async readby(entity, operation, key, value) {
        let json = "{\"" + key + "\":" + value + "}";
        let e = await api.read(this._entityType + "." + operation, json);
        return e;
    }
    async create(entity) {
        await class_validator_1.validateOrReject(entity);
        let e = await api.create(this._entityType + ".create", entity);
        let t = new (Object.getPrototypeOf(entity).constructor)();
        return helper_1.instance.ObjectClone(t, e);
    }
    async update(entity) {
        await class_validator_1.validateOrReject(entity);
        let e = await api.update(this._entityType + ".update", entity);
        let t = new (Object.getPrototypeOf(entity).constructor)();
        return helper_1.instance.ObjectClone(t, e);
    }
    async upsert(entity, reference) {
        await class_validator_1.validateOrReject(entity);
        let e = await api.upsert(this._entityType + ".upsert", entity, reference);
        let t = new (Object.getPrototypeOf(entity).constructor)();
        return helper_1.instance.ObjectClone(t, e);
    }
    async delete(id) {
        let json = "{\"" + this._entityType + "_id\":" + id + "}";
        return await api.delete(this._entityType + ".ldelete", json);
    }
}
exports.ServiceAPI = ServiceAPI;
class ServiceSubClassAPI extends ServiceAPI {
    constructor(entityType, subclass) {
        super(entityType);
        this._EntitySubClass = subclass;
    }
    get entitySubClass() {
        return this._EntitySubClass;
    }
    async readAll(entity, params) {
        if (api.isConnected) {
            return await api.operation(this._EntitySubClass + ".readall", params).then((results) => {
                if (results.error) {
                    if (dialogs_1.instance) {
                        dialogs_1.instance.alert("Error", results.error.message);
                    }
                    return Promise.reject(results);
                }
                else {
                    let res = results.map((r) => {
                        let t = new (Object.getPrototypeOf(entity).constructor)();
                        return helper_1.instance.ObjectClone(t, r);
                    });
                    //
                    return Promise.resolve(res);
                }
            });
        }
        else {
            return [];
        }
    }
}
exports.ServiceSubClassAPI = ServiceSubClassAPI;
//# sourceMappingURL=serviceapi.js.map