"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TripHelper = exports.TRIP_STATES = exports.TRIP_STATUS = void 0;
const dayjs_1 = __importDefault(require("dayjs"));
exports.TRIP_STATUS = {
    OFFERED: "OFFERED",
    UNFULFILLED: "UNFULFILLED",
    ACCEPTED: "ACCEPTED",
    ALLOCATED: "ALLOCATED",
    FAILED: "FAILED",
    COMPLETED: "COMPLETED",
    CANCELLED: "CANCELLED",
};
exports.TRIP_STATES = {
    OK: "ok",
    IN_PROGRESS: "in progress",
    OVERDUE: "unresolved",
    LATE: "incomplete",
    API_ERROR: "API error",
};
class TripHelper {
    get TRIP_STATUS() {
        return exports.TRIP_STATUS;
    }
    get TRIP_STATES() {
        return exports.TRIP_STATES;
    }
    getState(seconds, status) {
        let res = this.TRIP_STATES.OK;
        if (status == this.TRIP_STATUS.ACCEPTED) {
            res = this.TRIP_STATES.API_ERROR;
        }
        else if ((status == this.TRIP_STATUS.ALLOCATED) &&
            (((seconds / 60) > -60) && (seconds / 60) < 15)) {
            res = this.TRIP_STATES.IN_PROGRESS;
        }
        else if ((status == this.TRIP_STATUS.OFFERED || status == this.TRIP_STATUS.UNFULFILLED) &&
            (seconds < 0)) {
            res = this.TRIP_STATES.OVERDUE;
        }
        else if ((status != this.TRIP_STATUS.COMPLETED &&
            status != this.TRIP_STATUS.CANCELLED &&
            status != this.TRIP_STATUS.FAILED) &&
            (seconds < 0)) {
            res = this.TRIP_STATES.LATE;
        }
        return res;
    }
    isFailed(trip) {
        return trip.trip_status == exports.TRIP_STATUS.FAILED;
    }
    isCancelled(trip) {
        return trip.trip_status == exports.TRIP_STATUS.CANCELLED;
    }
    isCompleted(trip) {
        return trip.trip_status == exports.TRIP_STATUS.COMPLETED;
    }
    isFinalState(trip) {
        return this.isFailed(trip) || this.isCompleted(trip) || this.isCancelled(trip);
    }
    isOffered(leg) {
        return leg.trip_status == exports.TRIP_STATUS.OFFERED;
    }
    isAccepted(leg) {
        return leg.trip_status == exports.TRIP_STATUS.ACCEPTED;
    }
    isAllocated(leg) {
        return leg.trip_status == exports.TRIP_STATUS.ALLOCATED;
    }
    canCancel(leg) {
        return !this.isCompleted(leg) && !this.isCancelled(leg) && !this.isFailed(leg);
    }
    canRate(leg) {
        return this.isCompleted(leg);
    }
    canComplete(leg) {
        let now = dayjs_1.default();
        let diff = dayjs_1.default(leg.trip_pick_up_dt).diff(dayjs_1.default(), "second");
        //console.log({ label: "canComplete", now: now, pu: leg.trip_pick_up_dt, diff: diff });
        return this.isAllocated(leg) && diff < 0;
    }
    canUnableToService(leg) {
        let diff = dayjs_1.default(leg.trip_pick_up_dt).diff(dayjs_1.default(), "second");
        return this.isAllocated(leg) && diff > 0;
    }
    canEdit(leg, isTransportProvider) {
        if (isTransportProvider) {
            return this.isAllocated(leg);
        }
        return !this.isCancelled(leg)
            && !this.isCompleted(leg)
            && !this.isAccepted(leg)
            && !this.isFailed(leg);
    }
    isReturnLeg(leg) {
        return leg.properties.appointment_pick_up_type;
    }
}
exports.TripHelper = TripHelper;
//# sourceMappingURL=triphelper.js.map