"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.debounce = exports.HEREApi = exports.DialogState = exports.Pagination = void 0;
const api_1 = require("./api");
const calculations_1 = require("./calculations");
class Pagination {
    constructor(defaultSortColumn) {
        this.loading = false;
        this.itemsPerPage = 10;
        this.totalItems = 0;
        this.lastPage = 0;
        this.filters = [];
        this.params = [];
        this.defaultSortColumn = defaultSortColumn;
        this.sortBy = { descending: false, column: defaultSortColumn };
        this.filters = [];
    }
    setSortBy(column, descending) {
        let isModified = this.sortBy.column != column || this.sortBy.descending != descending;
        if (column) {
            this.sortBy.column = column;
            this.sortBy.descending = descending;
        }
        else {
            this.sortBy.column = this.defaultSortColumn;
            this.sortBy.descending = false;
        }
        return isModified;
    }
    indexOfByProperty(list, name, id) {
        let res = -1;
        for (let i = 0; i <= list.length - 1; i++) {
            let item = list[i];
            if (item[name] == id) {
                res = i;
                break;
            }
        }
        return res;
    }
    setFilter(column, value, operator) {
        let ndx = this.indexOfByProperty(this.filters, "column", column);
        if (ndx >= 0) {
            this.filters.splice(ndx, 1);
        }
        let isInvalid = (!value || value.length == 0 || value[0] == null);
        if (!isInvalid) {
            this.filters.push({ column: column, values: value, operator: operator });
        }
    }
    getRequestOptions(pageStart, itemPerPage) {
        return {
            offset: pageStart,
            limit: itemPerPage,
            filters: this.filters,
            params: this.params,
            order_by: { [this.sortBy.column]: this.sortBy.descending ? "DESC" : "ASC" },
        };
    }
}
exports.Pagination = Pagination;
class DialogState {
    constructor() {
        this.show = false;
        this.valid = false;
        this.isEdit = false;
        this.loading = false;
        this.review = false;
    }
}
exports.DialogState = DialogState;
class HEREApi {
    static async search(maxResults, query) {
        let api = api_1.Api.instance();
        return api.operation("address_api.search", { maxresults: maxResults, query: query });
    }
    static async locationDetails(locationId) {
        let api = api_1.Api.instance();
        return api.operation("address_api.details", { locationid: locationId });
    }
    static async calculateRoute(origin, dest) {
        let api = api_1.Api.instance();
        return api.operation("address_api.route_calculation", { origin: origin, destination: dest });
    }
    static async calculateRouteSummary(fromLocationId, toLocationId) {
        let addrToDetails = await this.locationDetails(fromLocationId);
        let addrFromDetails = await this.locationDetails(toLocationId);
        try {
            let fromLoc = addrFromDetails.response.view[0].result[0].location;
            let origin = {
                timezone: fromLoc.adminInfo.timeZone,
                position: fromLoc.displayPosition,
                mapView: fromLoc.mapView
            };
            let toLoc = addrToDetails.response.view[0].result[0].location;
            let destination = {
                timezone: toLoc.adminInfo.timeZone,
                position: toLoc.displayPosition,
                mapView: toLoc.mapView
            };
            addrFromDetails.response.view[0];
            let x = fromLoc.displayPosition;
            let y = toLoc.displayPosition;
            let from = x.latitude + "," + x.longitude;
            let to = y.latitude + "," + y.longitude;
            let route = await HEREApi.calculateRoute(from, to);
            let rsummary = route.routes[0].sections[0].summary;
            let api = api_1.Api.instance();
            rsummary.unit = api.distanceUnit;
            try {
                rsummary.duration = (Number(rsummary.duration) / 60);
                let dist = calculations_1.Calculations.m2km(Number(rsummary.length));
                rsummary.distance = rsummary.unit == calculations_1.DISTANCE_UNITS.KM ? dist : calculations_1.Calculations.convertDistance(dist, calculations_1.DISTANCE_UNITS.KM, calculations_1.DISTANCE_UNITS.MI);
            }
            catch (e) {
                rsummary.duration = null;
                rsummary.distance = null;
                rsummary.unit = "";
            }
            return { origin: origin, destination: destination, summary: rsummary };
        }
        catch (e) {
            throw new Error(e.message);
        }
    }
}
exports.HEREApi = HEREApi;
function debounce(fn, delay) {
    var timeoutID = 0;
    return function () {
        if (timeoutID) {
            clearTimeout(timeoutID);
        }
        var args = arguments;
        const that = this;
        timeoutID = setTimeout(function () {
            fn.apply(that, args);
        }, delay);
    };
}
exports.debounce = debounce;
//# sourceMappingURL=utility.js.map